# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from delphix.api.gateway.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from delphix.api.gateway.model.api_classification_config import APIClassificationConfig
from delphix.api.gateway.model.ased_source_link_source_parameters import ASEDSourceLinkSourceParameters
from delphix.api.gateway.model.ased_source_link_source_parameters_all_of import ASEDSourceLinkSourceParametersAllOf
from delphix.api.gateway.model.access_group import AccessGroup
from delphix.api.gateway.model.access_group_account_ids_request import AccessGroupAccountIdsRequest
from delphix.api.gateway.model.access_group_scope import AccessGroupScope
from delphix.api.gateway.model.access_group_scopes_request import AccessGroupScopesRequest
from delphix.api.gateway.model.access_group_update_parameters import AccessGroupUpdateParameters
from delphix.api.gateway.model.account import Account
from delphix.api.gateway.model.account_create_parameter import AccountCreateParameter
from delphix.api.gateway.model.account_create_response import AccountCreateResponse
from delphix.api.gateway.model.account_login_parameter import AccountLoginParameter
from delphix.api.gateway.model.account_ui_profiles_response import AccountUiProfilesResponse
from delphix.api.gateway.model.account_update_parameter import AccountUpdateParameter
from delphix.api.gateway.model.add_engine_to_hyperscale_response import AddEngineToHyperscaleResponse
from delphix.api.gateway.model.add_engine_to_job_response import AddEngineToJobResponse
from delphix.api.gateway.model.add_ui_profiles_response import AddUiProfilesResponse
from delphix.api.gateway.model.additional_mount_point import AdditionalMountPoint
from delphix.api.gateway.model.algorithm import Algorithm
from delphix.api.gateway.model.algorithm_config_validate_request import AlgorithmConfigValidateRequest
from delphix.api.gateway.model.algorithm_config_validate_response import AlgorithmConfigValidateResponse
from delphix.api.gateway.model.algorithm_create_request import AlgorithmCreateRequest
from delphix.api.gateway.model.algorithm_create_response import AlgorithmCreateResponse
from delphix.api.gateway.model.algorithm_delete_response import AlgorithmDeleteResponse
from delphix.api.gateway.model.algorithm_field import AlgorithmField
from delphix.api.gateway.model.algorithm_update_request import AlgorithmUpdateRequest
from delphix.api.gateway.model.algorithm_update_response import AlgorithmUpdateResponse
from delphix.api.gateway.model.all_object_permissions_response import AllObjectPermissionsResponse
from delphix.api.gateway.model.always_allowed_permission import AlwaysAllowedPermission
from delphix.api.gateway.model.always_allowed_permission_request import AlwaysAllowedPermissionRequest
from delphix.api.gateway.model.api_classification_object import ApiClassificationObject
from delphix.api.gateway.model.api_usage_data import ApiUsageData
from delphix.api.gateway.model.api_usage_report_response import ApiUsageReportResponse
from delphix.api.gateway.model.apikey_regenerate_parameter import ApikeyRegenerateParameter
from delphix.api.gateway.model.app_data_d_source_link_source_parameters import AppDataDSourceLinkSourceParameters
from delphix.api.gateway.model.app_data_d_source_link_source_parameters_all_of import AppDataDSourceLinkSourceParametersAllOf
from delphix.api.gateway.model.app_data_source_create_parameters import AppDataSourceCreateParameters
from delphix.api.gateway.model.app_data_source_update_parameters import AppDataSourceUpdateParameters
from delphix.api.gateway.model.ase_source_create_parameters import AseSourceCreateParameters
from delphix.api.gateway.model.ase_source_update_parameters import AseSourceUpdateParameters
from delphix.api.gateway.model.attach_cdbd_source_response import AttachCDBDSourceResponse
from delphix.api.gateway.model.attach_cdb_response import AttachCDBResponse
from delphix.api.gateway.model.attach_d_source_response import AttachDSourceResponse
from delphix.api.gateway.model.attach_staging_push_d_source_response import AttachStagingPushDSourceResponse
from delphix.api.gateway.model.audit_logs_summary import AuditLogsSummary
from delphix.api.gateway.model.audit_logs_summary_report_response import AuditLogsSummaryReportResponse
from delphix.api.gateway.model.audit_logs_summary_totals import AuditLogsSummaryTotals
from delphix.api.gateway.model.auto_tagging_config import AutoTaggingConfig
from delphix.api.gateway.model.base_d_source_link_source_parameters import BaseDSourceLinkSourceParameters
from delphix.api.gateway.model.base_deletetion_dependencies_response import BaseDeletetionDependenciesResponse
from delphix.api.gateway.model.base_export_transfer_strategy_parameters import BaseExportTransferStrategyParameters
from delphix.api.gateway.model.base_provision_vdb_parameters import BaseProvisionVDBParameters
from delphix.api.gateway.model.base_provision_vdb_parameters_all_of import BaseProvisionVDBParametersAllOf
from delphix.api.gateway.model.bookmark import Bookmark
from delphix.api.gateway.model.bookmark_compatible_environments_response import BookmarkCompatibleEnvironmentsResponse
from delphix.api.gateway.model.bookmark_compatible_repository_request import BookmarkCompatibleRepositoryRequest
from delphix.api.gateway.model.bookmark_create_parameters import BookmarkCreateParameters
from delphix.api.gateway.model.bookmark_d_sources import BookmarkDSources
from delphix.api.gateway.model.bookmark_paa_s_databases import BookmarkPaaSDatabases
from delphix.api.gateway.model.bookmark_paa_s_instances import BookmarkPaaSInstances
from delphix.api.gateway.model.bookmark_vdbs import BookmarkVDBs
from delphix.api.gateway.model.bundle_upload_event import BundleUploadEvent
from delphix.api.gateway.model.cdb import CDB
from delphix.api.gateway.model.cancel_job_collection_execution_response import CancelJobCollectionExecutionResponse
from delphix.api.gateway.model.cdb_d_source import CdbDSource
from delphix.api.gateway.model.change_license_parameters import ChangeLicenseParameters
from delphix.api.gateway.model.change_password_parameter import ChangePasswordParameter
from delphix.api.gateway.model.classifier import Classifier
from delphix.api.gateway.model.classifier_create_request import ClassifierCreateRequest
from delphix.api.gateway.model.classifier_create_response import ClassifierCreateResponse
from delphix.api.gateway.model.classifier_delete_response import ClassifierDeleteResponse
from delphix.api.gateway.model.classifier_update_request import ClassifierUpdateRequest
from delphix.api.gateway.model.classifier_update_response import ClassifierUpdateResponse
from delphix.api.gateway.model.classifiers_list_response import ClassifiersListResponse
from delphix.api.gateway.model.classifiers_search_response import ClassifiersSearchResponse
from delphix.api.gateway.model.cleanup_execution_response import CleanupExecutionResponse
from delphix.api.gateway.model.cloud_account import CloudAccount
from delphix.api.gateway.model.cloud_account_delete_parameters import CloudAccountDeleteParameters
from delphix.api.gateway.model.cloud_account_metadata import CloudAccountMetadata
from delphix.api.gateway.model.cloud_account_metadata_parameters import CloudAccountMetadataParameters
from delphix.api.gateway.model.cloud_account_parameters import CloudAccountParameters
from delphix.api.gateway.model.cloud_tag import CloudTag
from delphix.api.gateway.model.cloud_tags_request import CloudTagsRequest
from delphix.api.gateway.model.cloud_tags_response import CloudTagsResponse
from delphix.api.gateway.model.cluster_node_instance import ClusterNodeInstance
from delphix.api.gateway.model.commvault_connectivity_check_parameters import CommvaultConnectivityCheckParameters
from delphix.api.gateway.model.compliance_application_setting import ComplianceApplicationSetting
from delphix.api.gateway.model.compliance_application_setting_update_request import ComplianceApplicationSettingUpdateRequest
from delphix.api.gateway.model.compliance_application_settings_list_response import ComplianceApplicationSettingsListResponse
from delphix.api.gateway.model.compliance_application_settings_search_response import ComplianceApplicationSettingsSearchResponse
from delphix.api.gateway.model.compliance_job import ComplianceJob
from delphix.api.gateway.model.compliance_job_collection import ComplianceJobCollection
from delphix.api.gateway.model.compliance_job_collection_members import ComplianceJobCollectionMembers
from delphix.api.gateway.model.compliance_job_connectors_response import ComplianceJobConnectorsResponse
from delphix.api.gateway.model.compliance_job_script import ComplianceJobScript
from delphix.api.gateway.model.compliance_node import ComplianceNode
from delphix.api.gateway.model.compliance_node_delete_response import ComplianceNodeDeleteResponse
from delphix.api.gateway.model.compliance_node_log_content_response import ComplianceNodeLogContentResponse
from delphix.api.gateway.model.compliance_node_log_content_response_log_page_info import ComplianceNodeLogContentResponseLogPageInfo
from delphix.api.gateway.model.compliance_node_log_file_details import ComplianceNodeLogFileDetails
from delphix.api.gateway.model.compliance_node_log_file_details_response import ComplianceNodeLogFileDetailsResponse
from delphix.api.gateway.model.compliance_node_register_request import ComplianceNodeRegisterRequest
from delphix.api.gateway.model.compliance_node_register_response import ComplianceNodeRegisterResponse
from delphix.api.gateway.model.compliance_node_update_request import ComplianceNodeUpdateRequest
from delphix.api.gateway.model.compliance_node_update_response import ComplianceNodeUpdateResponse
from delphix.api.gateway.model.config_settings_stg import ConfigSettingsStg
from delphix.api.gateway.model.connection_property import ConnectionProperty
from delphix.api.gateway.model.connectivity_check_parameters import ConnectivityCheckParameters
from delphix.api.gateway.model.connectivity_check_response import ConnectivityCheckResponse
from delphix.api.gateway.model.connector import Connector
from delphix.api.gateway.model.connector_create_request import ConnectorCreateRequest
from delphix.api.gateway.model.connector_create_response import ConnectorCreateResponse
from delphix.api.gateway.model.connector_delete_response import ConnectorDeleteResponse
from delphix.api.gateway.model.connector_test_request import ConnectorTestRequest
from delphix.api.gateway.model.connector_test_response import ConnectorTestResponse
from delphix.api.gateway.model.connector_type_enum import ConnectorTypeEnum
from delphix.api.gateway.model.connector_update_parameters import ConnectorUpdateParameters
from delphix.api.gateway.model.consumer import Consumer
from delphix.api.gateway.model.containerization_state_enum import ContainerizationStateEnum
from delphix.api.gateway.model.convert_data_layout_request import ConvertDataLayoutRequest
from delphix.api.gateway.model.convert_data_layout_response import ConvertDataLayoutResponse
from delphix.api.gateway.model.copy_masking_job_parameters import CopyMaskingJobParameters
from delphix.api.gateway.model.copy_masking_job_response import CopyMaskingJobResponse
from delphix.api.gateway.model.create_app_data_source_response import CreateAppDataSourceResponse
from delphix.api.gateway.model.create_ase_source_response import CreateAseSourceResponse
from delphix.api.gateway.model.create_bookmark_response import CreateBookmarkResponse
from delphix.api.gateway.model.create_cloud_account_parameters import CreateCloudAccountParameters
from delphix.api.gateway.model.create_cloud_account_parameters_all_of import CreateCloudAccountParametersAllOf
from delphix.api.gateway.model.create_cloud_account_response import CreateCloudAccountResponse
from delphix.api.gateway.model.create_compliance_job_collection_request import CreateComplianceJobCollectionRequest
from delphix.api.gateway.model.create_compliance_job_collection_response import CreateComplianceJobCollectionResponse
from delphix.api.gateway.model.create_compliance_job_request import CreateComplianceJobRequest
from delphix.api.gateway.model.create_compliance_job_response import CreateComplianceJobResponse
from delphix.api.gateway.model.create_database_template_response import CreateDatabaseTemplateResponse
from delphix.api.gateway.model.create_environment_response import CreateEnvironmentResponse
from delphix.api.gateway.model.create_environment_user_response import CreateEnvironmentUserResponse
from delphix.api.gateway.model.create_hook_template_parameters import CreateHookTemplateParameters
from delphix.api.gateway.model.create_hook_template_response import CreateHookTemplateResponse
from delphix.api.gateway.model.create_host_response import CreateHostResponse
from delphix.api.gateway.model.create_hyperscale_connector_response import CreateHyperscaleConnectorResponse
from delphix.api.gateway.model.create_hyperscale_mount_point_response import CreateHyperscaleMountPointResponse
from delphix.api.gateway.model.create_job_orchestrator_request import CreateJobOrchestratorRequest
from delphix.api.gateway.model.create_job_orchestrator_response import CreateJobOrchestratorResponse
from delphix.api.gateway.model.create_masking_job_request import CreateMaskingJobRequest
from delphix.api.gateway.model.create_masking_job_response import CreateMaskingJobResponse
from delphix.api.gateway.model.create_mssql_source_response import CreateMssqlSourceResponse
from delphix.api.gateway.model.create_okv_client_parameters import CreateOkvClientParameters
from delphix.api.gateway.model.create_okv_client_response import CreateOkvClientResponse
from delphix.api.gateway.model.create_oracle_listener_params import CreateOracleListenerParams
from delphix.api.gateway.model.create_oracle_listener_response import CreateOracleListenerResponse
from delphix.api.gateway.model.create_oracle_source_response import CreateOracleSourceResponse
from delphix.api.gateway.model.create_paa_s_database_connector_parameters import CreatePaaSDatabaseConnectorParameters
from delphix.api.gateway.model.create_paa_s_database_connector_response import CreatePaaSDatabaseConnectorResponse
from delphix.api.gateway.model.create_postgres_source_response import CreatePostgresSourceResponse
from delphix.api.gateway.model.create_replication_profile_parameters import CreateReplicationProfileParameters
from delphix.api.gateway.model.create_replication_profile_response import CreateReplicationProfileResponse
from delphix.api.gateway.model.create_repository_params import CreateRepositoryParams
from delphix.api.gateway.model.create_repository_response import CreateRepositoryResponse
from delphix.api.gateway.model.create_role import CreateRole
from delphix.api.gateway.model.create_vdb_group_order import CreateVDBGroupOrder
from delphix.api.gateway.model.create_vdb_group_request import CreateVDBGroupRequest
from delphix.api.gateway.model.create_vdb_group_response import CreateVDBGroupResponse
from delphix.api.gateway.model.create_virtualization_policy_parameters import CreateVirtualizationPolicyParameters
from delphix.api.gateway.model.create_virtualization_policy_response import CreateVirtualizationPolicyResponse
from delphix.api.gateway.model.credentials_env_variable import CredentialsEnvVariable
from delphix.api.gateway.model.dct_product_telemetry_bundle_administration_info import DCTProductTelemetryBundleAdministrationInfo
from delphix.api.gateway.model.dct_product_telemetry_bundle_d_source_info import DCTProductTelemetryBundleDSourceInfo
from delphix.api.gateway.model.dct_product_telemetry_bundle_environment_info import DCTProductTelemetryBundleEnvironmentInfo
from delphix.api.gateway.model.dct_product_telemetry_bundle_object_counts import DCTProductTelemetryBundleObjectCounts
from delphix.api.gateway.model.dct_product_telemetry_bundle_vdb_info import DCTProductTelemetryBundleVDBInfo
from delphix.api.gateway.model.d_source import DSource
from delphix.api.gateway.model.d_source_consumption_data import DSourceConsumptionData
from delphix.api.gateway.model.d_source_consumption_report_response import DSourceConsumptionReportResponse
from delphix.api.gateway.model.d_source_hooks import DSourceHooks
from delphix.api.gateway.model.d_source_snapshot_parameters import DSourceSnapshotParameters
from delphix.api.gateway.model.d_source_usage_data import DSourceUsageData
from delphix.api.gateway.model.d_source_usage_report_response import DSourceUsageReportResponse
from delphix.api.gateway.model.data_class import DataClass
from delphix.api.gateway.model.data_class_add_algorithms_request import DataClassAddAlgorithmsRequest
from delphix.api.gateway.model.data_class_add_algorithms_response import DataClassAddAlgorithmsResponse
from delphix.api.gateway.model.data_class_algorithm_info import DataClassAlgorithmInfo
from delphix.api.gateway.model.data_class_create_request import DataClassCreateRequest
from delphix.api.gateway.model.data_class_create_response import DataClassCreateResponse
from delphix.api.gateway.model.data_class_delete_response import DataClassDeleteResponse
from delphix.api.gateway.model.data_class_remove_algorithms_request import DataClassRemoveAlgorithmsRequest
from delphix.api.gateway.model.data_class_remove_algorithms_response import DataClassRemoveAlgorithmsResponse
from delphix.api.gateway.model.data_class_update_request import DataClassUpdateRequest
from delphix.api.gateway.model.data_class_update_response import DataClassUpdateResponse
from delphix.api.gateway.model.data_classes_list_response import DataClassesListResponse
from delphix.api.gateway.model.data_classes_search_response import DataClassesSearchResponse
from delphix.api.gateway.model.data_connection import DataConnection
from delphix.api.gateway.model.data_connection_capability import DataConnectionCapability
from delphix.api.gateway.model.data_connection_update_parameters import DataConnectionUpdateParameters
from delphix.api.gateway.model.data_layout import DataLayout
from delphix.api.gateway.model.data_library import DataLibrary
from delphix.api.gateway.model.data_point_by_location_parameters import DataPointByLocationParameters
from delphix.api.gateway.model.data_point_by_snapshot_parameters import DataPointBySnapshotParameters
from delphix.api.gateway.model.data_point_by_timestamp_parameters import DataPointByTimestampParameters
from delphix.api.gateway.model.data_point_from_bookmark_parameters import DataPointFromBookmarkParameters
from delphix.api.gateway.model.data_risk_data import DataRiskData
from delphix.api.gateway.model.data_risk_report_totals import DataRiskReportTotals
from delphix.api.gateway.model.database_column_metadata import DatabaseColumnMetadata
from delphix.api.gateway.model.database_column_metadata_list_response import DatabaseColumnMetadataListResponse
from delphix.api.gateway.model.database_column_metadata_search_response import DatabaseColumnMetadataSearchResponse
from delphix.api.gateway.model.database_column_metadata_update_request import DatabaseColumnMetadataUpdateRequest
from delphix.api.gateway.model.database_column_metadata_update_response import DatabaseColumnMetadataUpdateResponse
from delphix.api.gateway.model.database_connectivity_check_parameters import DatabaseConnectivityCheckParameters
from delphix.api.gateway.model.database_table_metadata import DatabaseTableMetadata
from delphix.api.gateway.model.database_table_metadata_list_response import DatabaseTableMetadataListResponse
from delphix.api.gateway.model.database_table_metadata_parameters import DatabaseTableMetadataParameters
from delphix.api.gateway.model.database_table_metadata_search_response import DatabaseTableMetadataSearchResponse
from delphix.api.gateway.model.database_template import DatabaseTemplate
from delphix.api.gateway.model.database_template_create_parameters import DatabaseTemplateCreateParameters
from delphix.api.gateway.model.dataset_group import DatasetGroup
from delphix.api.gateway.model.dataset_performance_analytics import DatasetPerformanceAnalytics
from delphix.api.gateway.model.dataset_performance_analytics_request import DatasetPerformanceAnalyticsRequest
from delphix.api.gateway.model.dataset_performance_analytics_response import DatasetPerformanceAnalyticsResponse
from delphix.api.gateway.model.dataset_performance_analytics_summary import DatasetPerformanceAnalyticsSummary
from delphix.api.gateway.model.dataset_performance_analytics_summary_response import DatasetPerformanceAnalyticsSummaryResponse
from delphix.api.gateway.model.dct_product_telemetry_bundle import DctProductTelemetryBundle
from delphix.api.gateway.model.dct_product_telemetry_bundle_api_telemetry import DctProductTelemetryBundleApiTelemetry
from delphix.api.gateway.model.dct_product_telemetry_bundle_compliance_job import DctProductTelemetryBundleComplianceJob
from delphix.api.gateway.model.dct_product_telemetry_bundle_compliance_node import DctProductTelemetryBundleComplianceNode
from delphix.api.gateway.model.dct_product_telemetry_bundle_compliance_object_counts import DctProductTelemetryBundleComplianceObjectCounts
from delphix.api.gateway.model.dct_product_telemetry_bundle_connector import DctProductTelemetryBundleConnector
from delphix.api.gateway.model.dct_product_telemetry_bundle_continuous_data_engine_storage import DctProductTelemetryBundleContinuousDataEngineStorage
from delphix.api.gateway.model.dct_product_telemetry_bundle_data_connection_storage import DctProductTelemetryBundleDataConnectionStorage
from delphix.api.gateway.model.dct_product_telemetry_bundle_execution import DctProductTelemetryBundleExecution
from delphix.api.gateway.model.dct_product_telemetry_bundle_hyperscale_orchestrator import DctProductTelemetryBundleHyperscaleOrchestrator
from delphix.api.gateway.model.dct_product_telemetry_bundle_job_orchestrator import DctProductTelemetryBundleJobOrchestrator
from delphix.api.gateway.model.dct_product_telemetry_bundle_license_info import DctProductTelemetryBundleLicenseInfo
from delphix.api.gateway.model.dct_product_telemetry_bundle_product_history import DctProductTelemetryBundleProductHistory
from delphix.api.gateway.model.dct_product_telemetry_bundle_product_info import DctProductTelemetryBundleProductInfo
from delphix.api.gateway.model.dct_product_telemetry_bundle_registered_engine import DctProductTelemetryBundleRegisteredEngine
from delphix.api.gateway.model.dct_product_telemetry_bundle_rule_set import DctProductTelemetryBundleRuleSet
from delphix.api.gateway.model.dct_product_telemetry_data_connection import DctProductTelemetryDataConnection
from delphix.api.gateway.model.delete_bookmark_response import DeleteBookmarkResponse
from delphix.api.gateway.model.delete_cdbd_source_response import DeleteCDBDSourceResponse
from delphix.api.gateway.model.delete_cdb_parameters import DeleteCDBParameters
from delphix.api.gateway.model.delete_cdb_response import DeleteCDBResponse
from delphix.api.gateway.model.delete_cloud_tag import DeleteCloudTag
from delphix.api.gateway.model.delete_compliance_job_collection_response import DeleteComplianceJobCollectionResponse
from delphix.api.gateway.model.delete_compliance_job_response import DeleteComplianceJobResponse
from delphix.api.gateway.model.delete_d_source_request import DeleteDSourceRequest
from delphix.api.gateway.model.delete_d_source_response import DeleteDSourceResponse
from delphix.api.gateway.model.delete_d_source_response_all_of import DeleteDSourceResponseAllOf
from delphix.api.gateway.model.delete_database_template_response import DeleteDatabaseTemplateResponse
from delphix.api.gateway.model.delete_engine_response import DeleteEngineResponse
from delphix.api.gateway.model.delete_environment_response import DeleteEnvironmentResponse
from delphix.api.gateway.model.delete_environment_user_response import DeleteEnvironmentUserResponse
from delphix.api.gateway.model.delete_held_space_response import DeleteHeldSpaceResponse
from delphix.api.gateway.model.delete_host_response import DeleteHostResponse
from delphix.api.gateway.model.delete_hyperscale_connector_response import DeleteHyperscaleConnectorResponse
from delphix.api.gateway.model.delete_hyperscale_mount_point_response import DeleteHyperscaleMountPointResponse
from delphix.api.gateway.model.delete_job_orchestrator_response import DeleteJobOrchestratorResponse
from delphix.api.gateway.model.delete_masking_job_response import DeleteMaskingJobResponse
from delphix.api.gateway.model.delete_okv_client_response import DeleteOkvClientResponse
from delphix.api.gateway.model.delete_oracle_listener_response import DeleteOracleListenerResponse
from delphix.api.gateway.model.delete_paa_s_database_parameters import DeletePaaSDatabaseParameters
from delphix.api.gateway.model.delete_paa_s_database_response import DeletePaaSDatabaseResponse
from delphix.api.gateway.model.delete_paa_s_instance_parameters import DeletePaaSInstanceParameters
from delphix.api.gateway.model.delete_paa_s_instance_response import DeletePaaSInstanceResponse
from delphix.api.gateway.model.delete_scope_object_tags import DeleteScopeObjectTags
from delphix.api.gateway.model.delete_scoped_object_item import DeleteScopedObjectItem
from delphix.api.gateway.model.delete_snapshot_parameters import DeleteSnapshotParameters
from delphix.api.gateway.model.delete_snapshot_response import DeleteSnapshotResponse
from delphix.api.gateway.model.delete_source_response import DeleteSourceResponse
from delphix.api.gateway.model.delete_staging_cdb_response import DeleteStagingCDBResponse
from delphix.api.gateway.model.delete_staging_cdb_parameters import DeleteStagingCdbParameters
from delphix.api.gateway.model.delete_tag import DeleteTag
from delphix.api.gateway.model.delete_timeflow_parameters import DeleteTimeflowParameters
from delphix.api.gateway.model.delete_timeflow_response import DeleteTimeflowResponse
from delphix.api.gateway.model.delete_vcdb_parameters import DeleteVCDBParameters
from delphix.api.gateway.model.delete_vcdb_response import DeleteVCDBResponse
from delphix.api.gateway.model.delete_vdb_parameters import DeleteVDBParameters
from delphix.api.gateway.model.delete_vdb_response import DeleteVDBResponse
from delphix.api.gateway.model.deletion_dependencies_response import DeletionDependenciesResponse
from delphix.api.gateway.model.deletion_dependencies_tree_response import DeletionDependenciesTreeResponse
from delphix.api.gateway.model.deletion_dependency_object import DeletionDependencyObject
from delphix.api.gateway.model.deletion_dependency_object_type import DeletionDependencyObjectType
from delphix.api.gateway.model.deletion_dependency_prerequisite_action import DeletionDependencyPrerequisiteAction
from delphix.api.gateway.model.dependency import Dependency
from delphix.api.gateway.model.deprovision_paa_s_databases_response import DeprovisionPaaSDatabasesResponse
from delphix.api.gateway.model.deprovision_paa_s_instance_response import DeprovisionPaaSInstanceResponse
from delphix.api.gateway.model.detach_cdbd_source_response import DetachCDBDSourceResponse
from delphix.api.gateway.model.detach_cdb_response import DetachCDBResponse
from delphix.api.gateway.model.detach_d_source_response import DetachDSourceResponse
from delphix.api.gateway.model.disable_cdbd_source_response import DisableCDBDSourceResponse
from delphix.api.gateway.model.disable_cdb_parameters import DisableCDBParameters
from delphix.api.gateway.model.disable_cdb_response import DisableCDBResponse
from delphix.api.gateway.model.disable_dsource_parameters import DisableDsourceParameters
from delphix.api.gateway.model.disable_dsource_response import DisableDsourceResponse
from delphix.api.gateway.model.disable_environment_response import DisableEnvironmentResponse
from delphix.api.gateway.model.disable_staging_cdb_response import DisableStagingCDBResponse
from delphix.api.gateway.model.disable_vcdb_parameters import DisableVCDBParameters
from delphix.api.gateway.model.disable_vcdb_response import DisableVCDBResponse
from delphix.api.gateway.model.disable_vdb_group_parameters import DisableVDBGroupParameters
from delphix.api.gateway.model.disable_vdb_group_response import DisableVDBGroupResponse
from delphix.api.gateway.model.disable_vdb_parameters import DisableVDBParameters
from delphix.api.gateway.model.disable_vdb_response import DisableVDBResponse
from delphix.api.gateway.model.discovery_expression import DiscoveryExpression
from delphix.api.gateway.model.discovery_expressions_list_response import DiscoveryExpressionsListResponse
from delphix.api.gateway.model.discovery_expressions_search_response import DiscoveryExpressionsSearchResponse
from delphix.api.gateway.model.discovery_policies_list_response import DiscoveryPoliciesListResponse
from delphix.api.gateway.model.discovery_policies_search_response import DiscoveryPoliciesSearchResponse
from delphix.api.gateway.model.discovery_policy import DiscoveryPolicy
from delphix.api.gateway.model.discovery_policy_add_classifiers_request import DiscoveryPolicyAddClassifiersRequest
from delphix.api.gateway.model.discovery_policy_add_classifiers_response import DiscoveryPolicyAddClassifiersResponse
from delphix.api.gateway.model.discovery_policy_create_request import DiscoveryPolicyCreateRequest
from delphix.api.gateway.model.discovery_policy_create_response import DiscoveryPolicyCreateResponse
from delphix.api.gateway.model.discovery_policy_delete_response import DiscoveryPolicyDeleteResponse
from delphix.api.gateway.model.discovery_policy_remove_classifiers_request import DiscoveryPolicyRemoveClassifiersRequest
from delphix.api.gateway.model.discovery_policy_remove_classifiers_response import DiscoveryPolicyRemoveClassifiersResponse
from delphix.api.gateway.model.discovery_policy_update_request import DiscoveryPolicyUpdateRequest
from delphix.api.gateway.model.discovery_policy_update_response import DiscoveryPolicyUpdateResponse
from delphix.api.gateway.model.discovery_result import DiscoveryResult
from delphix.api.gateway.model.domain import Domain
from delphix.api.gateway.model.effective_scope import EffectiveScope
from delphix.api.gateway.model.enable_ai_status import EnableAiStatus
from delphix.api.gateway.model.enable_cdbd_source_response import EnableCDBDSourceResponse
from delphix.api.gateway.model.enable_cdb_parameters import EnableCDBParameters
from delphix.api.gateway.model.enable_cdb_response import EnableCDBResponse
from delphix.api.gateway.model.enable_dsource_parameters import EnableDsourceParameters
from delphix.api.gateway.model.enable_dsource_response import EnableDsourceResponse
from delphix.api.gateway.model.enable_environment_response import EnableEnvironmentResponse
from delphix.api.gateway.model.enable_staging_cdb_response import EnableStagingCDBResponse
from delphix.api.gateway.model.enable_vcdb_parameters import EnableVCDBParameters
from delphix.api.gateway.model.enable_vcdb_response import EnableVCDBResponse
from delphix.api.gateway.model.enable_vdb_group_parameters import EnableVDBGroupParameters
from delphix.api.gateway.model.enable_vdb_group_response import EnableVDBGroupResponse
from delphix.api.gateway.model.enable_vdb_parameters import EnableVDBParameters
from delphix.api.gateway.model.enable_vdb_response import EnableVDBResponse
from delphix.api.gateway.model.engine import Engine
from delphix.api.gateway.model.engine_auto_tagging_config_update_parameters import EngineAutoTaggingConfigUpdateParameters
from delphix.api.gateway.model.engine_global_object_state_data import EngineGlobalObjectStateData
from delphix.api.gateway.model.engine_historical_storage_summary import EngineHistoricalStorageSummary
from delphix.api.gateway.model.engine_id_body import EngineIdBody
from delphix.api.gateway.model.engine_performance_analytic import EnginePerformanceAnalytic
from delphix.api.gateway.model.engine_performance_analytic_report_response import EnginePerformanceAnalyticReportResponse
from delphix.api.gateway.model.engine_performance_analytic_trend import EnginePerformanceAnalyticTrend
from delphix.api.gateway.model.engine_performance_analytic_trend_datapoint import EnginePerformanceAnalyticTrendDatapoint
from delphix.api.gateway.model.engine_performance_analytic_trend_response import EnginePerformanceAnalyticTrendResponse
from delphix.api.gateway.model.engine_registration_parameter import EngineRegistrationParameter
from delphix.api.gateway.model.engine_storage_capacity_data import EngineStorageCapacityData
from delphix.api.gateway.model.engine_storage_capacity_data_response import EngineStorageCapacityDataResponse
from delphix.api.gateway.model.engine_storage_capacity_dependency_data import EngineStorageCapacityDependencyData
from delphix.api.gateway.model.engine_storage_capacity_dependency_data_all_of import EngineStorageCapacityDependencyDataAllOf
from delphix.api.gateway.model.engine_storage_dataset_type import EngineStorageDatasetType
from delphix.api.gateway.model.engine_upgrade_history import EngineUpgradeHistory
from delphix.api.gateway.model.environment import Environment
from delphix.api.gateway.model.environment_create_parameters import EnvironmentCreateParameters
from delphix.api.gateway.model.environment_repository import EnvironmentRepository
from delphix.api.gateway.model.environment_repository_all_of import EnvironmentRepositoryAllOf
from delphix.api.gateway.model.environment_update_parameters import EnvironmentUpdateParameters
from delphix.api.gateway.model.environment_user import EnvironmentUser
from delphix.api.gateway.model.environment_user_params import EnvironmentUserParams
from delphix.api.gateway.model.error import Error
from delphix.api.gateway.model.error_response import ErrorResponse
from delphix.api.gateway.model.errors import Errors
from delphix.api.gateway.model.execute_compliance_job_collection_response import ExecuteComplianceJobCollectionResponse
from delphix.api.gateway.model.execute_compliance_job_request import ExecuteComplianceJobRequest
from delphix.api.gateway.model.execute_compliance_job_response import ExecuteComplianceJobResponse
from delphix.api.gateway.model.execute_masking_job_parameters import ExecuteMaskingJobParameters
from delphix.api.gateway.model.execute_masking_job_response import ExecuteMaskingJobResponse
from delphix.api.gateway.model.execute_paa_s_database_compliance_job_response import ExecutePaaSDatabaseComplianceJobResponse
from delphix.api.gateway.model.execute_replication_profile_response import ExecuteReplicationProfileResponse
from delphix.api.gateway.model.execution import Execution
from delphix.api.gateway.model.execution_cancel_parameters import ExecutionCancelParameters
from delphix.api.gateway.model.execution_component import ExecutionComponent
from delphix.api.gateway.model.execution_component_log import ExecutionComponentLog
from delphix.api.gateway.model.execution_components_list_response import ExecutionComponentsListResponse
from delphix.api.gateway.model.execution_components_search_response import ExecutionComponentsSearchResponse
from delphix.api.gateway.model.execution_event import ExecutionEvent
from delphix.api.gateway.model.execution_log import ExecutionLog
from delphix.api.gateway.model.execution_status import ExecutionStatus
from delphix.api.gateway.model.execution_status_reason import ExecutionStatusReason
from delphix.api.gateway.model.export_by_location_parameters import ExportByLocationParameters
from delphix.api.gateway.model.export_by_location_parameters_all_of import ExportByLocationParametersAllOf
from delphix.api.gateway.model.export_by_snapshot_parameters import ExportBySnapshotParameters
from delphix.api.gateway.model.export_by_snapshot_parameters_all_of import ExportBySnapshotParametersAllOf
from delphix.api.gateway.model.export_by_timestamp_parameters import ExportByTimestampParameters
from delphix.api.gateway.model.export_by_timestamp_parameters_all_of import ExportByTimestampParametersAllOf
from delphix.api.gateway.model.export_cleanup_parameters import ExportCleanupParameters
from delphix.api.gateway.model.export_cleanup_response import ExportCleanupResponse
from delphix.api.gateway.model.export_db_timeflow_point_parameters import ExportDBTimeflowPointParameters
from delphix.api.gateway.model.export_finalize_parameters import ExportFinalizeParameters
from delphix.api.gateway.model.export_finalize_response import ExportFinalizeResponse
from delphix.api.gateway.model.export_from_bookmark_parameters import ExportFromBookmarkParameters
from delphix.api.gateway.model.export_from_bookmark_parameters_all_of import ExportFromBookmarkParametersAllOf
from delphix.api.gateway.model.export_response import ExportResponse
from delphix.api.gateway.model.failover_namespace_parameters import FailoverNamespaceParameters
from delphix.api.gateway.model.fetch_table_names_request import FetchTableNamesRequest
from delphix.api.gateway.model.fetch_table_names_response import FetchTableNamesResponse
from delphix.api.gateway.model.file_mapping_bookmark_parameters import FileMappingBookmarkParameters
from delphix.api.gateway.model.file_mapping_location_parameters import FileMappingLocationParameters
from delphix.api.gateway.model.file_mapping_result import FileMappingResult
from delphix.api.gateway.model.file_mapping_snapshot_parameters import FileMappingSnapshotParameters
from delphix.api.gateway.model.file_mapping_timestamp_parameters import FileMappingTimestampParameters
from delphix.api.gateway.model.filesystem_layout_parameters import FilesystemLayoutParameters
from delphix.api.gateway.model.find_by_location_response import FindByLocationResponse
from delphix.api.gateway.model.find_by_timestamp_response import FindByTimestampResponse
from delphix.api.gateway.model.framework import Framework
from delphix.api.gateway.model.generate_data_attribute import GenerateDataAttribute
from delphix.api.gateway.model.generate_data_operation import GenerateDataOperation
from delphix.api.gateway.model.generate_data_request import GenerateDataRequest
from delphix.api.gateway.model.generate_data_response import GenerateDataResponse
from delphix.api.gateway.model.generate_execution_pdf_report_response import GenerateExecutionPdfReportResponse
from delphix.api.gateway.model.get_all_generate_data_operations_response import GetAllGenerateDataOperationsResponse
from delphix.api.gateway.model.get_all_llm_gateways_response import GetAllLlmGatewaysResponse
from delphix.api.gateway.model.get_all_llm_models_response import GetAllLlmModelsResponse
from delphix.api.gateway.model.get_connector_driver_support_tasks_response import GetConnectorDriverSupportTasksResponse
from delphix.api.gateway.model.get_data_risk_report_response import GetDataRiskReportResponse
from delphix.api.gateway.model.get_engine_global_object_state_report_response import GetEngineGlobalObjectStateReportResponse
from delphix.api.gateway.model.get_generate_data_values_response import GetGenerateDataValuesResponse
from delphix.api.gateway.model.get_snapshot_deletion_dependencies_response import GetSnapshotDeletionDependenciesResponse
from delphix.api.gateway.model.global_properties import GlobalProperties
from delphix.api.gateway.model.global_tag import GlobalTag
from delphix.api.gateway.model.global_tag_permissions import GlobalTagPermissions
from delphix.api.gateway.model.global_tag_usage import GlobalTagUsage
from delphix.api.gateway.model.hashicorp_vault import HashicorpVault
from delphix.api.gateway.model.held_space_deletion_dependencies_response import HeldSpaceDeletionDependenciesResponse
from delphix.api.gateway.model.historical_storage_summary import HistoricalStorageSummary
from delphix.api.gateway.model.historical_storage_summary_aggregate import HistoricalStorageSummaryAggregate
from delphix.api.gateway.model.hook import Hook
from delphix.api.gateway.model.hook_template import HookTemplate
from delphix.api.gateway.model.hook_template_delete_job_response import HookTemplateDeleteJobResponse
from delphix.api.gateway.model.hook_template_update_job_response import HookTemplateUpdateJobResponse
from delphix.api.gateway.model.host import Host
from delphix.api.gateway.model.host_create_parameters import HostCreateParameters
from delphix.api.gateway.model.host_update_parameters import HostUpdateParameters
from delphix.api.gateway.model.hyperscale_column_or_field import HyperscaleColumnOrField
from delphix.api.gateway.model.hyperscale_connector import HyperscaleConnector
from delphix.api.gateway.model.hyperscale_connector_create_parameters import HyperscaleConnectorCreateParameters
from delphix.api.gateway.model.hyperscale_connector_update_parameters import HyperscaleConnectorUpdateParameters
from delphix.api.gateway.model.hyperscale_data_type_enum import HyperscaleDataTypeEnum
from delphix.api.gateway.model.hyperscale_dataset import HyperscaleDataset
from delphix.api.gateway.model.hyperscale_dataset_table_or_file import HyperscaleDatasetTableOrFile
from delphix.api.gateway.model.hyperscale_dataset_table_or_file_update_parameters import HyperscaleDatasetTableOrFileUpdateParameters
from delphix.api.gateway.model.hyperscale_dataset_update_parameters import HyperscaleDatasetUpdateParameters
from delphix.api.gateway.model.hyperscale_instance import HyperscaleInstance
from delphix.api.gateway.model.hyperscale_instance_registration_parameter import HyperscaleInstanceRegistrationParameter
from delphix.api.gateway.model.hyperscale_instance_update_params import HyperscaleInstanceUpdateParams
from delphix.api.gateway.model.hyperscale_mount_point import HyperscaleMountPoint
from delphix.api.gateway.model.hyperscale_mount_point_update_parameters import HyperscaleMountPointUpdateParameters
from delphix.api.gateway.model.hyperscale_task_error import HyperscaleTaskError
from delphix.api.gateway.model.hyperscale_task_event import HyperscaleTaskEvent
from delphix.api.gateway.model.import_engine_account_request import ImportEngineAccountRequest
from delphix.api.gateway.model.import_engine_accounts_response import ImportEngineAccountsResponse
from delphix.api.gateway.model.import_engine_bookmark_response import ImportEngineBookmarkResponse
from delphix.api.gateway.model.in_place_export_parameters import InPlaceExportParameters
from delphix.api.gateway.model.in_place_export_parameters_all_of import InPlaceExportParametersAllOf
from delphix.api.gateway.model.job import Job
from delphix.api.gateway.model.job_collection_execution import JobCollectionExecution
from delphix.api.gateway.model.job_collection_failure_handling_enum import JobCollectionFailureHandlingEnum
from delphix.api.gateway.model.job_orchestrator import JobOrchestrator
from delphix.api.gateway.model.job_result_response import JobResultResponse
from delphix.api.gateway.model.job_task import JobTask
from delphix.api.gateway.model.job_task_event import JobTaskEvent
from delphix.api.gateway.model.kdc_servers import KDCServers
from delphix.api.gateway.model.kerberos_config import KerberosConfig
from delphix.api.gateway.model.ldap_config_params import LDAPConfigParams
from delphix.api.gateway.model.llm_upload_response import LLMUploadResponse
from delphix.api.gateway.model.latency_test_request import LatencyTestRequest
from delphix.api.gateway.model.latency_test_request_all_of import LatencyTestRequestAllOf
from delphix.api.gateway.model.latest_snapshots_response import LatestSnapshotsResponse
from delphix.api.gateway.model.ldap_config_validate_parameter import LdapConfigValidateParameter
from delphix.api.gateway.model.ldap_validate_response import LdapValidateResponse
from delphix.api.gateway.model.license_info import LicenseInfo
from delphix.api.gateway.model.license_tier import LicenseTier
from delphix.api.gateway.model.license_usage_connection_response import LicenseUsageConnectionResponse
from delphix.api.gateway.model.license_usage_day_record import LicenseUsageDayRecord
from delphix.api.gateway.model.license_usage_response import LicenseUsageResponse
from delphix.api.gateway.model.license_usage_response_current_sources_size import LicenseUsageResponseCurrentSourcesSize
from delphix.api.gateway.model.license_usage_response_other_entitlements import LicenseUsageResponseOtherEntitlements
from delphix.api.gateway.model.license_usage_response_other_entitlements_continuous_vault import LicenseUsageResponseOtherEntitlementsContinuousVault
from delphix.api.gateway.model.license_usage_response_other_entitlements_elastic_data import LicenseUsageResponseOtherEntitlementsElasticData
from delphix.api.gateway.model.license_usage_response_source_type_count import LicenseUsageResponseSourceTypeCount
from delphix.api.gateway.model.license_usage_time_series_response import LicenseUsageTimeSeriesResponse
from delphix.api.gateway.model.license_usage_type_record import LicenseUsageTypeRecord
from delphix.api.gateway.model.link_d_source_default_request import LinkDSourceDefaultRequest
from delphix.api.gateway.model.link_d_source_response import LinkDSourceResponse
from delphix.api.gateway.model.link_staging_push_d_source_default_request import LinkStagingPushDSourceDefaultRequest
from delphix.api.gateway.model.list_access_groups_response import ListAccessGroupsResponse
from delphix.api.gateway.model.list_accounts_response import ListAccountsResponse
from delphix.api.gateway.model.list_algorithm_dependencies_response import ListAlgorithmDependenciesResponse
from delphix.api.gateway.model.list_algorithms_response import ListAlgorithmsResponse
from delphix.api.gateway.model.list_bookmarks_by_paa_s_database_response import ListBookmarksByPaaSDatabaseResponse
from delphix.api.gateway.model.list_bookmarks_by_paa_s_instance_response import ListBookmarksByPaaSInstanceResponse
from delphix.api.gateway.model.list_bookmarks_by_vdb_groups_response import ListBookmarksByVDBGroupsResponse
from delphix.api.gateway.model.list_bookmarks_by_vdb_response import ListBookmarksByVDBResponse
from delphix.api.gateway.model.list_bookmarks_response import ListBookmarksResponse
from delphix.api.gateway.model.list_cdbd_sources_response import ListCDBDSourcesResponse
from delphix.api.gateway.model.list_cdbs_response import ListCDBsResponse
from delphix.api.gateway.model.list_cloud_accounts_response import ListCloudAccountsResponse
from delphix.api.gateway.model.list_compliance_job_collections_response import ListComplianceJobCollectionsResponse
from delphix.api.gateway.model.list_compliance_jobs_response import ListComplianceJobsResponse
from delphix.api.gateway.model.list_compliance_nodes_response import ListComplianceNodesResponse
from delphix.api.gateway.model.list_connection_properties_response import ListConnectionPropertiesResponse
from delphix.api.gateway.model.list_connectors_masking_jobs_response import ListConnectorsMaskingJobsResponse
from delphix.api.gateway.model.list_connectors_response import ListConnectorsResponse
from delphix.api.gateway.model.list_d_sources_response import ListDSourcesResponse
from delphix.api.gateway.model.list_data_connections_response import ListDataConnectionsResponse
from delphix.api.gateway.model.list_data_layout_response import ListDataLayoutResponse
from delphix.api.gateway.model.list_data_library_response import ListDataLibraryResponse
from delphix.api.gateway.model.list_database_templates_response import ListDatabaseTemplatesResponse
from delphix.api.gateway.model.list_discovery_results_response import ListDiscoveryResultsResponse
from delphix.api.gateway.model.list_environment_users import ListEnvironmentUsers
from delphix.api.gateway.model.list_environments_response import ListEnvironmentsResponse
from delphix.api.gateway.model.list_execution_events_response import ListExecutionEventsResponse
from delphix.api.gateway.model.list_executions_response import ListExecutionsResponse
from delphix.api.gateway.model.list_groups_response import ListGroupsResponse
from delphix.api.gateway.model.list_hashicorp_vaults_response import ListHashicorpVaultsResponse
from delphix.api.gateway.model.list_hook_templates_response import ListHookTemplatesResponse
from delphix.api.gateway.model.list_hyperscale_connectors_response import ListHyperscaleConnectorsResponse
from delphix.api.gateway.model.list_hyperscale_dataset_tables_or_files_response import ListHyperscaleDatasetTablesOrFilesResponse
from delphix.api.gateway.model.list_hyperscale_datasets_response import ListHyperscaleDatasetsResponse
from delphix.api.gateway.model.list_hyperscale_instances_response import ListHyperscaleInstancesResponse
from delphix.api.gateway.model.list_hyperscale_mount_points_response import ListHyperscaleMountPointsResponse
from delphix.api.gateway.model.list_job_collection_executions_response import ListJobCollectionExecutionsResponse
from delphix.api.gateway.model.list_job_orchestrator_queued_operations_response import ListJobOrchestratorQueuedOperationsResponse
from delphix.api.gateway.model.list_job_orchestrators_response import ListJobOrchestratorsResponse
from delphix.api.gateway.model.list_jobs_response import ListJobsResponse
from delphix.api.gateway.model.list_kerberos_configs_response import ListKerberosConfigsResponse
from delphix.api.gateway.model.list_masking_environments_response import ListMaskingEnvironmentsResponse
from delphix.api.gateway.model.list_masking_file_consumers_response import ListMaskingFileConsumersResponse
from delphix.api.gateway.model.list_masking_files_response import ListMaskingFilesResponse
from delphix.api.gateway.model.list_masking_job_source_engines_response import ListMaskingJobSourceEnginesResponse
from delphix.api.gateway.model.list_masking_jobs_response import ListMaskingJobsResponse
from delphix.api.gateway.model.list_masking_plugins_response import ListMaskingPluginsResponse
from delphix.api.gateway.model.list_namespaces_response import ListNamespacesResponse
from delphix.api.gateway.model.list_okv_clients_response import ListOkvClientsResponse
from delphix.api.gateway.model.list_paa_s_databases_response import ListPaaSDatabasesResponse
from delphix.api.gateway.model.list_paa_s_instances_response import ListPaaSInstancesResponse
from delphix.api.gateway.model.list_paa_s_plugins_response import ListPaaSPluginsResponse
from delphix.api.gateway.model.list_paa_s_snapshot_response import ListPaaSSnapshotResponse
from delphix.api.gateway.model.list_password_vaults_response import ListPasswordVaultsResponse
from delphix.api.gateway.model.list_registered_engines_response import ListRegisteredEnginesResponse
from delphix.api.gateway.model.list_replication_profiles_response import ListReplicationProfilesResponse
from delphix.api.gateway.model.list_reporting_schedule_response import ListReportingScheduleResponse
from delphix.api.gateway.model.list_roles_response import ListRolesResponse
from delphix.api.gateway.model.list_snapshots_response import ListSnapshotsResponse
from delphix.api.gateway.model.list_sources_response import ListSourcesResponse
from delphix.api.gateway.model.list_staging_cdbs_response import ListStagingCdbsResponse
from delphix.api.gateway.model.list_staging_sources_response import ListStagingSourcesResponse
from delphix.api.gateway.model.list_sub_connections_response import ListSubConnectionsResponse
from delphix.api.gateway.model.list_tag_permissions_response import ListTagPermissionsResponse
from delphix.api.gateway.model.list_tag_usages_response import ListTagUsagesResponse
from delphix.api.gateway.model.list_tags_response import ListTagsResponse
from delphix.api.gateway.model.list_timeflows_response import ListTimeflowsResponse
from delphix.api.gateway.model.list_toolkit_response import ListToolkitResponse
from delphix.api.gateway.model.list_vcdbs_response import ListVCDBsResponse
from delphix.api.gateway.model.list_vdb_groups_by_bookmark_response import ListVDBGroupsByBookmarkResponse
from delphix.api.gateway.model.list_vdb_groups_response import ListVDBGroupsResponse
from delphix.api.gateway.model.list_vdbs_response import ListVDBsResponse
from delphix.api.gateway.model.list_virtualization_actions_response import ListVirtualizationActionsResponse
from delphix.api.gateway.model.list_virtualization_alerts_response import ListVirtualizationAlertsResponse
from delphix.api.gateway.model.list_virtualization_faults_response import ListVirtualizationFaultsResponse
from delphix.api.gateway.model.list_virtualization_jobs_response import ListVirtualizationJobsResponse
from delphix.api.gateway.model.list_virtualization_policies_response import ListVirtualizationPoliciesResponse
from delphix.api.gateway.model.llm_gateway import LlmGateway
from delphix.api.gateway.model.llm_model import LlmModel
from delphix.api.gateway.model.location_compatible_environments_response import LocationCompatibleEnvironmentsResponse
from delphix.api.gateway.model.location_compatible_repository_request import LocationCompatibleRepositoryRequest
from delphix.api.gateway.model.lock_vdb_group_parameters import LockVDBGroupParameters
from delphix.api.gateway.model.lock_vdb_parameters import LockVDBParameters
from delphix.api.gateway.model.login_token import LoginToken
from delphix.api.gateway.model.mssql_cluster_listener import MSSQLClusterListener
from delphix.api.gateway.model.mssqld_source_attach_source_parameters import MSSQLDSourceAttachSourceParameters
from delphix.api.gateway.model.mssqld_source_link_source_parameters import MSSQLDSourceLinkSourceParameters
from delphix.api.gateway.model.mssqld_source_link_source_parameters_all_of import MSSQLDSourceLinkSourceParametersAllOf
from delphix.api.gateway.model.mssqld_source_staging_push_attach_source_parameters import MSSQLDSourceStagingPushAttachSourceParameters
from delphix.api.gateway.model.mssqld_source_staging_push_link_source_parameters import MSSQLDSourceStagingPushLinkSourceParameters
from delphix.api.gateway.model.mssqld_source_staging_push_link_source_parameters_all_of import MSSQLDSourceStagingPushLinkSourceParametersAllOf
from delphix.api.gateway.model.mssql_listener_type_enum import MSSQLListenerTypeEnum
from delphix.api.gateway.model.mssql_source_update_parameters import MSSQLSourceUpdateParameters
from delphix.api.gateway.model.masking_environment import MaskingEnvironment
from delphix.api.gateway.model.masking_execution_metrics import MaskingExecutionMetrics
from delphix.api.gateway.model.masking_execution_metrics_report_response import MaskingExecutionMetricsReportResponse
from delphix.api.gateway.model.masking_file_download_url_create_response import MaskingFileDownloadUrlCreateResponse
from delphix.api.gateway.model.masking_file_upload import MaskingFileUpload
from delphix.api.gateway.model.masking_file_upload_response import MaskingFileUploadResponse
from delphix.api.gateway.model.masking_file_upload_update_parameters import MaskingFileUploadUpdateParameters
from delphix.api.gateway.model.masking_job import MaskingJob
from delphix.api.gateway.model.masking_job_connectors_response import MaskingJobConnectorsResponse
from delphix.api.gateway.model.masking_job_source_engine import MaskingJobSourceEngine
from delphix.api.gateway.model.masking_job_with_connector_role import MaskingJobWithConnectorRole
from delphix.api.gateway.model.masking_plugin import MaskingPlugin
from delphix.api.gateway.model.masking_plugin_create_request import MaskingPluginCreateRequest
from delphix.api.gateway.model.masking_plugin_create_response import MaskingPluginCreateResponse
from delphix.api.gateway.model.masking_plugin_update_request import MaskingPluginUpdateRequest
from delphix.api.gateway.model.masking_plugin_update_response import MaskingPluginUpdateResponse
from delphix.api.gateway.model.masking_ruleset import MaskingRuleset
from delphix.api.gateway.model.masking_type_enum import MaskingTypeEnum
from delphix.api.gateway.model.metadata_db_info import MetadataDbInfo
from delphix.api.gateway.model.migrate_compatible_environments_response import MigrateCompatibleEnvironmentsResponse
from delphix.api.gateway.model.migrate_job_rerun_request import MigrateJobRerunRequest
from delphix.api.gateway.model.migrate_masking_job_parameters import MigrateMaskingJobParameters
from delphix.api.gateway.model.migrate_masking_job_response import MigrateMaskingJobResponse
from delphix.api.gateway.model.migrate_vdb_parameters import MigrateVDBParameters
from delphix.api.gateway.model.migrate_vdb_response import MigrateVDBResponse
from delphix.api.gateway.model.mssql_ag_replica import MssqlAgReplica
from delphix.api.gateway.model.mssql_config_type_enum import MssqlConfigTypeEnum
from delphix.api.gateway.model.mssql_source_create_parameters import MssqlSourceCreateParameters
from delphix.api.gateway.model.name_value_pair import NameValuePair
from delphix.api.gateway.model.namespace import Namespace
from delphix.api.gateway.model.namespace_commit_failover_job_response import NamespaceCommitFailoverJobResponse
from delphix.api.gateway.model.namespace_delete_job_response import NamespaceDeleteJobResponse
from delphix.api.gateway.model.namespace_discard_job_response import NamespaceDiscardJobResponse
from delphix.api.gateway.model.namespace_failback_job_response import NamespaceFailbackJobResponse
from delphix.api.gateway.model.namespace_failover_job_response import NamespaceFailoverJobResponse
from delphix.api.gateway.model.namespace_update_job_response import NamespaceUpdateJobResponse
from delphix.api.gateway.model.netbackup_connectivity_check_parameters import NetbackupConnectivityCheckParameters
from delphix.api.gateway.model.network_dsp_test_request import NetworkDSPTestRequest
from delphix.api.gateway.model.network_dsp_test_request_all_of import NetworkDSPTestRequestAllOf
from delphix.api.gateway.model.network_dsp_test_result import NetworkDSPTestResult
from delphix.api.gateway.model.network_dsp_test_result_all_of import NetworkDSPTestResultAllOf
from delphix.api.gateway.model.network_latency_test_result import NetworkLatencyTestResult
from delphix.api.gateway.model.network_latency_test_result_all_of import NetworkLatencyTestResultAllOf
from delphix.api.gateway.model.network_test_base_result import NetworkTestBaseResult
from delphix.api.gateway.model.network_test_parameters_request import NetworkTestParametersRequest
from delphix.api.gateway.model.network_test_response import NetworkTestResponse
from delphix.api.gateway.model.network_throughput_test_request import NetworkThroughputTestRequest
from delphix.api.gateway.model.network_throughput_test_request_all_of import NetworkThroughputTestRequestAllOf
from delphix.api.gateway.model.network_throughput_test_result import NetworkThroughputTestResult
from delphix.api.gateway.model.nfs_version_reason_enum import NfsVersionReasonEnum
from delphix.api.gateway.model.object_permission_access_groups import ObjectPermissionAccessGroups
from delphix.api.gateway.model.object_permission_account import ObjectPermissionAccount
from delphix.api.gateway.model.object_permissions_response import ObjectPermissionsResponse
from delphix.api.gateway.model.object_type_enum import ObjectTypeEnum
from delphix.api.gateway.model.object_type_property import ObjectTypeProperty
from delphix.api.gateway.model.okv_client import OkvClient
from delphix.api.gateway.model.oracle_active_instance import OracleActiveInstance
from delphix.api.gateway.model.oracle_asm_export_by_location_parameters import OracleAsmExportByLocationParameters
from delphix.api.gateway.model.oracle_asm_export_by_location_parameters_all_of import OracleAsmExportByLocationParametersAllOf
from delphix.api.gateway.model.oracle_asm_export_by_snapshot_parameters import OracleAsmExportBySnapshotParameters
from delphix.api.gateway.model.oracle_asm_export_by_timestamp_parameters import OracleAsmExportByTimestampParameters
from delphix.api.gateway.model.oracle_asm_export_from_bookmark_parameters import OracleAsmExportFromBookmarkParameters
from delphix.api.gateway.model.oracle_asm_export_response import OracleAsmExportResponse
from delphix.api.gateway.model.oracle_asm_in_place_export_parameters import OracleAsmInPlaceExportParameters
from delphix.api.gateway.model.oracle_asm_in_place_vdb_export_response import OracleAsmInPlaceVDBExportResponse
from delphix.api.gateway.model.oracle_asm_layout_parameters import OracleAsmLayoutParameters
from delphix.api.gateway.model.oracle_attach_cdb_parameters import OracleAttachCdbParameters
from delphix.api.gateway.model.oracle_attach_cdb_parameters_all_of import OracleAttachCdbParametersAllOf
from delphix.api.gateway.model.oracle_attach_d_source_parameters import OracleAttachDSourceParameters
from delphix.api.gateway.model.oracle_attach_d_source_parameters_all_of import OracleAttachDSourceParametersAllOf
from delphix.api.gateway.model.oracle_attach_parameters import OracleAttachParameters
from delphix.api.gateway.model.oracle_cluster_node_instance import OracleClusterNodeInstance
from delphix.api.gateway.model.oracle_config_type_enum import OracleConfigTypeEnum
from delphix.api.gateway.model.oracle_custom_env_var import OracleCustomEnvVar
from delphix.api.gateway.model.oracle_d_source_link_source_parameters import OracleDSourceLinkSourceParameters
from delphix.api.gateway.model.oracle_d_source_link_source_parameters_all_of import OracleDSourceLinkSourceParametersAllOf
from delphix.api.gateway.model.oracle_link_staging_push_d_source_default_request import OracleLinkStagingPushDSourceDefaultRequest
from delphix.api.gateway.model.oracle_listener import OracleListener
from delphix.api.gateway.model.oracle_listener_type_enum import OracleListenerTypeEnum
from delphix.api.gateway.model.oracle_logsync_mode_type_enum import OracleLogsyncModeTypeEnum
from delphix.api.gateway.model.oracle_rac_database_instance import OracleRACDatabaseInstance
from delphix.api.gateway.model.oracle_rac_custom_env_file import OracleRacCustomEnvFile
from delphix.api.gateway.model.oracle_rac_custom_env_var import OracleRacCustomEnvVar
from delphix.api.gateway.model.oracle_service import OracleService
from delphix.api.gateway.model.oracle_source_create_parameters import OracleSourceCreateParameters
from delphix.api.gateway.model.oracle_source_update_parameters import OracleSourceUpdateParameters
from delphix.api.gateway.model.oracle_staging_push_d_source_link_source_parameters import OracleStagingPushDSourceLinkSourceParameters
from delphix.api.gateway.model.oracle_staging_push_d_source_link_source_parameters_all_of import OracleStagingPushDSourceLinkSourceParametersAllOf
from delphix.api.gateway.model.oracle_tde_keystore_config_type_enum import OracleTdeKeystoreConfigTypeEnum
from delphix.api.gateway.model.oracle_verify_jdbc_connection_string_params import OracleVerifyJdbcConnectionStringParams
from delphix.api.gateway.model.oracle_virtual_ip import OracleVirtualIP
from delphix.api.gateway.model.paa_s_database import PaaSDatabase
from delphix.api.gateway.model.paa_s_instance import PaaSInstance
from delphix.api.gateway.model.paa_s_plugin import PaaSPlugin
from delphix.api.gateway.model.paa_s_snapshot import PaaSSnapshot
from delphix.api.gateway.model.paginated_response_metadata import PaginatedResponseMetadata
from delphix.api.gateway.model.password_policies_params import PasswordPoliciesParams
from delphix.api.gateway.model.password_vault import PasswordVault
from delphix.api.gateway.model.performance_analytics import PerformanceAnalytics
from delphix.api.gateway.model.permission_enum import PermissionEnum
from delphix.api.gateway.model.permission_object import PermissionObject
from delphix.api.gateway.model.permission_property import PermissionProperty
from delphix.api.gateway.model.permissions_request import PermissionsRequest
from delphix.api.gateway.model.plugin_region import PluginRegion
from delphix.api.gateway.model.plugin_type_enum import PluginTypeEnum
from delphix.api.gateway.model.policy_target_object import PolicyTargetObject
from delphix.api.gateway.model.policy_type import PolicyType
from delphix.api.gateway.model.postgres_source_create_parameters import PostgresSourceCreateParameters
from delphix.api.gateway.model.postgres_source_update_parameters import PostgresSourceUpdateParameters
from delphix.api.gateway.model.primary_environment_user_response import PrimaryEnvironmentUserResponse
from delphix.api.gateway.model.product_history import ProductHistory
from delphix.api.gateway.model.product_info import ProductInfo
from delphix.api.gateway.model.product_registration_offline_payload import ProductRegistrationOfflinePayload
from delphix.api.gateway.model.product_registration_online_payload import ProductRegistrationOnlinePayload
from delphix.api.gateway.model.provision_empty_vdb_parameters import ProvisionEmptyVDBParameters
from delphix.api.gateway.model.provision_empty_vdb_parameters_all_of import ProvisionEmptyVDBParametersAllOf
from delphix.api.gateway.model.provision_paa_s_database_base_parameters import ProvisionPaaSDatabaseBaseParameters
from delphix.api.gateway.model.provision_paa_s_database_from_bookmark_parameters import ProvisionPaaSDatabaseFromBookmarkParameters
from delphix.api.gateway.model.provision_paa_s_database_from_bookmark_parameters_all_of import ProvisionPaaSDatabaseFromBookmarkParametersAllOf
from delphix.api.gateway.model.provision_paa_s_database_from_bookmark_response import ProvisionPaaSDatabaseFromBookmarkResponse
from delphix.api.gateway.model.provision_paa_s_database_parameters import ProvisionPaaSDatabaseParameters
from delphix.api.gateway.model.provision_paa_s_database_parameters_all_of import ProvisionPaaSDatabaseParametersAllOf
from delphix.api.gateway.model.provision_paa_s_database_response import ProvisionPaaSDatabaseResponse
from delphix.api.gateway.model.provision_paa_s_instance_base_parameters import ProvisionPaaSInstanceBaseParameters
from delphix.api.gateway.model.provision_paa_s_instance_from_bookmark_parameters import ProvisionPaaSInstanceFromBookmarkParameters
from delphix.api.gateway.model.provision_paa_s_instance_from_bookmark_parameters_all_of import ProvisionPaaSInstanceFromBookmarkParametersAllOf
from delphix.api.gateway.model.provision_paa_s_instance_from_bookmark_response import ProvisionPaaSInstanceFromBookmarkResponse
from delphix.api.gateway.model.provision_paa_s_instance_parameters import ProvisionPaaSInstanceParameters
from delphix.api.gateway.model.provision_paa_s_instance_parameters_all_of import ProvisionPaaSInstanceParametersAllOf
from delphix.api.gateway.model.provision_paa_s_instance_response import ProvisionPaaSInstanceResponse
from delphix.api.gateway.model.provision_source import ProvisionSource
from delphix.api.gateway.model.provision_vdbby_location_defaults_request import ProvisionVDBByLocationDefaultsRequest
from delphix.api.gateway.model.provision_vdbby_location_parameters import ProvisionVDBByLocationParameters
from delphix.api.gateway.model.provision_vdbby_location_parameters_all_of import ProvisionVDBByLocationParametersAllOf
from delphix.api.gateway.model.provision_vdbby_snapshot_defaults_request import ProvisionVDBBySnapshotDefaultsRequest
from delphix.api.gateway.model.provision_vdbby_snapshot_parameters import ProvisionVDBBySnapshotParameters
from delphix.api.gateway.model.provision_vdbby_snapshot_parameters_all_of import ProvisionVDBBySnapshotParametersAllOf
from delphix.api.gateway.model.provision_vdbby_timestamp_defaults_request import ProvisionVDBByTimestampDefaultsRequest
from delphix.api.gateway.model.provision_vdbby_timestamp_parameters import ProvisionVDBByTimestampParameters
from delphix.api.gateway.model.provision_vdbby_timestamp_parameters_all_of import ProvisionVDBByTimestampParametersAllOf
from delphix.api.gateway.model.provision_vdb_from_bookmark_defaults_request import ProvisionVDBFromBookmarkDefaultsRequest
from delphix.api.gateway.model.provision_vdb_from_bookmark_parameters import ProvisionVDBFromBookmarkParameters
from delphix.api.gateway.model.provision_vdb_from_bookmark_parameters_all_of import ProvisionVDBFromBookmarkParametersAllOf
from delphix.api.gateway.model.provision_vdb_group_from_bookmark_parameters import ProvisionVDBGroupFromBookmarkParameters
from delphix.api.gateway.model.provision_vdb_group_from_bookmark_response import ProvisionVDBGroupFromBookmarkResponse
from delphix.api.gateway.model.provision_vdb_response import ProvisionVDBResponse
from delphix.api.gateway.model.proxy_configuration import ProxyConfiguration
from delphix.api.gateway.model.queued_operation import QueuedOperation
from delphix.api.gateway.model.re_import_masking_job_response import ReImportMaskingJobResponse
from delphix.api.gateway.model.re_provision_paa_s_database_parameters import ReProvisionPaaSDatabaseParameters
from delphix.api.gateway.model.re_provision_paa_s_instance_parameters import ReProvisionPaaSInstanceParameters
from delphix.api.gateway.model.reassign_sub_connection_request import ReassignSubConnectionRequest
from delphix.api.gateway.model.reassign_sub_connection_response import ReassignSubConnectionResponse
from delphix.api.gateway.model.refresh_environment_response import RefreshEnvironmentResponse
from delphix.api.gateway.model.refresh_logs_response import RefreshLogsResponse
from delphix.api.gateway.model.refresh_mode_enum import RefreshModeEnum
from delphix.api.gateway.model.refresh_paa_s_database_from_bookmark_parameters import RefreshPaaSDatabaseFromBookmarkParameters
from delphix.api.gateway.model.refresh_paa_s_database_parameters import RefreshPaaSDatabaseParameters
from delphix.api.gateway.model.refresh_paa_s_databases_from_bookmark_response import RefreshPaaSDatabasesFromBookmarkResponse
from delphix.api.gateway.model.refresh_paa_s_databases_response import RefreshPaaSDatabasesResponse
from delphix.api.gateway.model.refresh_paa_s_instance_from_bookmark_parameters import RefreshPaaSInstanceFromBookmarkParameters
from delphix.api.gateway.model.refresh_paa_s_instance_from_bookmark_response import RefreshPaaSInstanceFromBookmarkResponse
from delphix.api.gateway.model.refresh_paa_s_instance_parameters import RefreshPaaSInstanceParameters
from delphix.api.gateway.model.refresh_paa_s_instance_response import RefreshPaaSInstanceResponse
from delphix.api.gateway.model.refresh_rule_set_response import RefreshRuleSetResponse
from delphix.api.gateway.model.refresh_vdbby_location_parameters import RefreshVDBByLocationParameters
from delphix.api.gateway.model.refresh_vdbby_location_response import RefreshVDBByLocationResponse
from delphix.api.gateway.model.refresh_vdbby_snapshot_parameters import RefreshVDBBySnapshotParameters
from delphix.api.gateway.model.refresh_vdbby_snapshot_response import RefreshVDBBySnapshotResponse
from delphix.api.gateway.model.refresh_vdbby_timestamp_parameters import RefreshVDBByTimestampParameters
from delphix.api.gateway.model.refresh_vdbby_timestamp_parameters_all_of import RefreshVDBByTimestampParametersAllOf
from delphix.api.gateway.model.refresh_vdbby_timestamp_response import RefreshVDBByTimestampResponse
from delphix.api.gateway.model.refresh_vdb_from_bookmark_parameters import RefreshVDBFromBookmarkParameters
from delphix.api.gateway.model.refresh_vdb_from_bookmark_response import RefreshVDBFromBookmarkResponse
from delphix.api.gateway.model.refresh_vdb_group_by_snapshot_parameters import RefreshVDBGroupBySnapshotParameters
from delphix.api.gateway.model.refresh_vdb_group_by_timestamp_parameters import RefreshVDBGroupByTimestampParameters
from delphix.api.gateway.model.refresh_vdb_group_parameters import RefreshVDBGroupParameters
from delphix.api.gateway.model.refresh_vdb_group_response import RefreshVDBGroupResponse
from delphix.api.gateway.model.registered_engine import RegisteredEngine
from delphix.api.gateway.model.remove_engine_from_hyperscale_response import RemoveEngineFromHyperscaleResponse
from delphix.api.gateway.model.remove_engine_from_job_response import RemoveEngineFromJobResponse
from delphix.api.gateway.model.remove_masking_job_parameters import RemoveMaskingJobParameters
from delphix.api.gateway.model.replica import Replica
from delphix.api.gateway.model.replication_profile import ReplicationProfile
from delphix.api.gateway.model.replication_profile_delete_job_response import ReplicationProfileDeleteJobResponse
from delphix.api.gateway.model.replication_profile_update_job_response import ReplicationProfileUpdateJobResponse
from delphix.api.gateway.model.reporting_schedule import ReportingSchedule
from delphix.api.gateway.model.reporting_schedule_create_parameters import ReportingScheduleCreateParameters
from delphix.api.gateway.model.repository import Repository
from delphix.api.gateway.model.repository_delete_job_response import RepositoryDeleteJobResponse
from delphix.api.gateway.model.reprovision_paa_s_database_response import ReprovisionPaaSDatabaseResponse
from delphix.api.gateway.model.reprovision_paa_s_instance_response import ReprovisionPaaSInstanceResponse
from delphix.api.gateway.model.reset_password_parameter import ResetPasswordParameter
from delphix.api.gateway.model.restart_execution_response import RestartExecutionResponse
from delphix.api.gateway.model.role import Role
from delphix.api.gateway.model.role_all_of import RoleAllOf
from delphix.api.gateway.model.role_update_parameters import RoleUpdateParameters
from delphix.api.gateway.model.rollback_vdbby_snapshot_parameters import RollbackVDBBySnapshotParameters
from delphix.api.gateway.model.rollback_vdbby_snapshot_response import RollbackVDBBySnapshotResponse
from delphix.api.gateway.model.rollback_vdbby_timestamp_parameters import RollbackVDBByTimestampParameters
from delphix.api.gateway.model.rollback_vdbby_timestamp_response import RollbackVDBByTimestampResponse
from delphix.api.gateway.model.rollback_vdb_from_bookmark_parameters import RollbackVDBFromBookmarkParameters
from delphix.api.gateway.model.rollback_vdb_from_bookmark_response import RollbackVDBFromBookmarkResponse
from delphix.api.gateway.model.rollback_vdb_group_parameters import RollbackVDBGroupParameters
from delphix.api.gateway.model.rollback_vdb_group_response import RollbackVDBGroupResponse
from delphix.api.gateway.model.rule_set import RuleSet
from delphix.api.gateway.model.rule_set_bulk_table_delta_update_request import RuleSetBulkTableDeltaUpdateRequest
from delphix.api.gateway.model.rule_set_bulk_table_delta_update_response import RuleSetBulkTableDeltaUpdateResponse
from delphix.api.gateway.model.rule_set_create_request import RuleSetCreateRequest
from delphix.api.gateway.model.rule_set_create_response import RuleSetCreateResponse
from delphix.api.gateway.model.rule_set_delete_response import RuleSetDeleteResponse
from delphix.api.gateway.model.rule_set_update_request import RuleSetUpdateRequest
from delphix.api.gateway.model.rule_set_update_response import RuleSetUpdateResponse
from delphix.api.gateway.model.rule_sets_list_response import RuleSetsListResponse
from delphix.api.gateway.model.rule_sets_search_response import RuleSetsSearchResponse
from delphix.api.gateway.model.saml_config_params import SAMLConfigParams
from delphix.api.gateway.model.saml_validation_response import SAMLValidationResponse
from delphix.api.gateway.model.smtp_config_params import SMTPConfigParams
from delphix.api.gateway.model.smtp_config_validate import SMTPConfigValidate
from delphix.api.gateway.model.ssh_verification_strategy import SSHVerificationStrategy
from delphix.api.gateway.model.scope_tag import ScopeTag
from delphix.api.gateway.model.scope_tags_request import ScopeTagsRequest
from delphix.api.gateway.model.scope_tags_response import ScopeTagsResponse
from delphix.api.gateway.model.scoped_object_item import ScopedObjectItem
from delphix.api.gateway.model.scoped_object_items_response import ScopedObjectItemsResponse
from delphix.api.gateway.model.scoped_objects_request import ScopedObjectsRequest
from delphix.api.gateway.model.search_access_groups_response import SearchAccessGroupsResponse
from delphix.api.gateway.model.search_accounts_response import SearchAccountsResponse
from delphix.api.gateway.model.search_algorithm_dependencies_response import SearchAlgorithmDependenciesResponse
from delphix.api.gateway.model.search_algorithms_response import SearchAlgorithmsResponse
from delphix.api.gateway.model.search_body import SearchBody
from delphix.api.gateway.model.search_bookmarks_by_paa_s_database_response import SearchBookmarksByPaaSDatabaseResponse
from delphix.api.gateway.model.search_bookmarks_by_paa_s_instance_response import SearchBookmarksByPaaSInstanceResponse
from delphix.api.gateway.model.search_bookmarks_by_vdb_groups_response import SearchBookmarksByVDBGroupsResponse
from delphix.api.gateway.model.search_bookmarks_by_vdb_response import SearchBookmarksByVDBResponse
from delphix.api.gateway.model.search_bookmarks_response import SearchBookmarksResponse
from delphix.api.gateway.model.search_cdbd_sources_response import SearchCDBDSourcesResponse
from delphix.api.gateway.model.search_cdbs_response import SearchCDBsResponse
from delphix.api.gateway.model.search_cloud_accounts_response import SearchCloudAccountsResponse
from delphix.api.gateway.model.search_compliance_job_collections_response import SearchComplianceJobCollectionsResponse
from delphix.api.gateway.model.search_compliance_jobs_response import SearchComplianceJobsResponse
from delphix.api.gateway.model.search_connectors_response import SearchConnectorsResponse
from delphix.api.gateway.model.search_d_sources_response import SearchDSourcesResponse
from delphix.api.gateway.model.search_data_connections_response import SearchDataConnectionsResponse
from delphix.api.gateway.model.search_data_layout_response import SearchDataLayoutResponse
from delphix.api.gateway.model.search_data_library_response import SearchDataLibraryResponse
from delphix.api.gateway.model.search_data_risk_report_response import SearchDataRiskReportResponse
from delphix.api.gateway.model.search_database_templates_response import SearchDatabaseTemplatesResponse
from delphix.api.gateway.model.search_dataset_group_response import SearchDatasetGroupResponse
from delphix.api.gateway.model.search_discovery_results_response import SearchDiscoveryResultsResponse
from delphix.api.gateway.model.search_engine_global_object_state_report_response import SearchEngineGlobalObjectStateReportResponse
from delphix.api.gateway.model.search_engines_response import SearchEnginesResponse
from delphix.api.gateway.model.search_environments_response import SearchEnvironmentsResponse
from delphix.api.gateway.model.search_execution_events_response import SearchExecutionEventsResponse
from delphix.api.gateway.model.search_executions_response import SearchExecutionsResponse
from delphix.api.gateway.model.search_hashicorp_vaults_response import SearchHashicorpVaultsResponse
from delphix.api.gateway.model.search_hook_templates_response import SearchHookTemplatesResponse
from delphix.api.gateway.model.search_hyperscale_connectors_response import SearchHyperscaleConnectorsResponse
from delphix.api.gateway.model.search_hyperscale_dataset_tables_or_files_response import SearchHyperscaleDatasetTablesOrFilesResponse
from delphix.api.gateway.model.search_hyperscale_datasets_response import SearchHyperscaleDatasetsResponse
from delphix.api.gateway.model.search_hyperscale_instances_response import SearchHyperscaleInstancesResponse
from delphix.api.gateway.model.search_hyperscale_mount_points_response import SearchHyperscaleMountPointsResponse
from delphix.api.gateway.model.search_job_collection_executions_response import SearchJobCollectionExecutionsResponse
from delphix.api.gateway.model.search_job_orchestrator_queued_operations_response import SearchJobOrchestratorQueuedOperationsResponse
from delphix.api.gateway.model.search_job_orchestrators_response import SearchJobOrchestratorsResponse
from delphix.api.gateway.model.search_jobs_response import SearchJobsResponse
from delphix.api.gateway.model.search_kerberos_configs_response import SearchKerberosConfigsResponse
from delphix.api.gateway.model.search_masking_environments_response import SearchMaskingEnvironmentsResponse
from delphix.api.gateway.model.search_masking_file_consumers_response import SearchMaskingFileConsumersResponse
from delphix.api.gateway.model.search_masking_files_response import SearchMaskingFilesResponse
from delphix.api.gateway.model.search_masking_job_source_engines_response import SearchMaskingJobSourceEnginesResponse
from delphix.api.gateway.model.search_masking_jobs_response import SearchMaskingJobsResponse
from delphix.api.gateway.model.search_masking_plugins_response import SearchMaskingPluginsResponse
from delphix.api.gateway.model.search_namespaces_response import SearchNamespacesResponse
from delphix.api.gateway.model.search_paa_s_databases_response import SearchPaaSDatabasesResponse
from delphix.api.gateway.model.search_paa_s_instances_response import SearchPaaSInstancesResponse
from delphix.api.gateway.model.search_paa_s_snapshot_response import SearchPaaSSnapshotResponse
from delphix.api.gateway.model.search_password_vault_response import SearchPasswordVaultResponse
from delphix.api.gateway.model.search_replication_profiles_response import SearchReplicationProfilesResponse
from delphix.api.gateway.model.search_reporting_schedule_response import SearchReportingScheduleResponse
from delphix.api.gateway.model.search_roles_response import SearchRolesResponse
from delphix.api.gateway.model.search_snapshots_response import SearchSnapshotsResponse
from delphix.api.gateway.model.search_sources_response import SearchSourcesResponse
from delphix.api.gateway.model.search_staging_cdbs_response import SearchStagingCdbsResponse
from delphix.api.gateway.model.search_staging_sources_response import SearchStagingSourcesResponse
from delphix.api.gateway.model.search_sub_connections_response import SearchSubConnectionsResponse
from delphix.api.gateway.model.search_tag_permissions_response import SearchTagPermissionsResponse
from delphix.api.gateway.model.search_tag_usages_response import SearchTagUsagesResponse
from delphix.api.gateway.model.search_tags_response import SearchTagsResponse
from delphix.api.gateway.model.search_timeflows_response import SearchTimeflowsResponse
from delphix.api.gateway.model.search_toolkit_response import SearchToolkitResponse
from delphix.api.gateway.model.search_vcdbs_response import SearchVCDBsResponse
from delphix.api.gateway.model.search_vdb_group_response import SearchVDBGroupResponse
from delphix.api.gateway.model.search_vdb_groups_by_bookmark_response import SearchVDBGroupsByBookmarkResponse
from delphix.api.gateway.model.search_vdbs_response import SearchVDBsResponse
from delphix.api.gateway.model.search_virtualization_actions_response import SearchVirtualizationActionsResponse
from delphix.api.gateway.model.search_virtualization_alerts_response import SearchVirtualizationAlertsResponse
from delphix.api.gateway.model.search_virtualization_faults_response import SearchVirtualizationFaultsResponse
from delphix.api.gateway.model.search_virtualization_jobs_response import SearchVirtualizationJobsResponse
from delphix.api.gateway.model.search_virtualization_policies_response import SearchVirtualizationPoliciesResponse
from delphix.api.gateway.model.search_virtualization_policy_targets_response import SearchVirtualizationPolicyTargetsResponse
from delphix.api.gateway.model.share_paa_s_snapshot_response import SharePaaSSnapshotResponse
from delphix.api.gateway.model.shared_snapshot_space import SharedSnapshotSpace
from delphix.api.gateway.model.shared_snapshot_space_response import SharedSnapshotSpaceResponse
from delphix.api.gateway.model.size_with_unit import SizeWithUnit
from delphix.api.gateway.model.snapshot import Snapshot
from delphix.api.gateway.model.snapshot_capacity import SnapshotCapacity
from delphix.api.gateway.model.snapshot_capacity_response import SnapshotCapacityResponse
from delphix.api.gateway.model.snapshot_compatible_environments_response import SnapshotCompatibleEnvironmentsResponse
from delphix.api.gateway.model.snapshot_compatible_repository_request import SnapshotCompatibleRepositoryRequest
from delphix.api.gateway.model.snapshot_d_source_response import SnapshotDSourceResponse
from delphix.api.gateway.model.snapshot_day_range import SnapshotDayRange
from delphix.api.gateway.model.snapshot_missing_log import SnapshotMissingLog
from delphix.api.gateway.model.snapshot_runtime import SnapshotRuntime
from delphix.api.gateway.model.snapshot_vdb_response import SnapshotVDBResponse
from delphix.api.gateway.model.snapshots_day_ranges_response import SnapshotsDayRangesResponse
from delphix.api.gateway.model.source import Source
from delphix.api.gateway.model.source_operation import SourceOperation
from delphix.api.gateway.model.staging_cdb import StagingCdb
from delphix.api.gateway.model.staging_compatible_environments_response import StagingCompatibleEnvironmentsResponse
from delphix.api.gateway.model.staging_source import StagingSource
from delphix.api.gateway.model.start_paa_s_instance_response import StartPaaSInstanceResponse
from delphix.api.gateway.model.start_vcdb_parameters import StartVCDBParameters
from delphix.api.gateway.model.start_vcdb_response import StartVCDBResponse
from delphix.api.gateway.model.start_vdb_group_parameters import StartVDBGroupParameters
from delphix.api.gateway.model.start_vdb_group_response import StartVDBGroupResponse
from delphix.api.gateway.model.start_vdb_parameters import StartVDBParameters
from delphix.api.gateway.model.start_vdb_response import StartVDBResponse
from delphix.api.gateway.model.stop_paa_s_instance_response import StopPaaSInstanceResponse
from delphix.api.gateway.model.stop_vcdb_parameters import StopVCDBParameters
from delphix.api.gateway.model.stop_vcdb_response import StopVCDBResponse
from delphix.api.gateway.model.stop_vdb_group_parameters import StopVDBGroupParameters
from delphix.api.gateway.model.stop_vdb_group_response import StopVDBGroupResponse
from delphix.api.gateway.model.stop_vdb_parameters import StopVDBParameters
from delphix.api.gateway.model.stop_vdb_response import StopVDBResponse
from delphix.api.gateway.model.storage_savings_report_summarized_data import StorageSavingsReportSummarizedData
from delphix.api.gateway.model.storage_savings_summary_data import StorageSavingsSummaryData
from delphix.api.gateway.model.storage_savings_summary_report_response import StorageSavingsSummaryReportResponse
from delphix.api.gateway.model.storage_summary_historical_data_point import StorageSummaryHistoricalDataPoint
from delphix.api.gateway.model.storage_summary_projected_data_point import StorageSummaryProjectedDataPoint
from delphix.api.gateway.model.sub_connection import SubConnection
from delphix.api.gateway.model.switch_timeflow_parameters import SwitchTimeflowParameters
from delphix.api.gateway.model.switch_timeflow_response import SwitchTimeflowResponse
from delphix.api.gateway.model.sync_engines_hyperscale_parameters import SyncEnginesHyperscaleParameters
from delphix.api.gateway.model.sync_engines_hyperscale_response import SyncEnginesHyperscaleResponse
from delphix.api.gateway.model.tag import Tag
from delphix.api.gateway.model.tags_request import TagsRequest
from delphix.api.gateway.model.tags_response import TagsResponse
from delphix.api.gateway.model.target_job_type import TargetJobType
from delphix.api.gateway.model.target_object_type import TargetObjectType
from delphix.api.gateway.model.target_policy_object_type import TargetPolicyObjectType
from delphix.api.gateway.model.task_event import TaskEvent
from delphix.api.gateway.model.timeflow import Timeflow
from delphix.api.gateway.model.timeflow_range import TimeflowRange
from delphix.api.gateway.model.timeflow_repair_request import TimeflowRepairRequest
from delphix.api.gateway.model.timeflow_repair_response import TimeflowRepairResponse
from delphix.api.gateway.model.timeflow_snapshot_range import TimeflowSnapshotRange
from delphix.api.gateway.model.timeflow_snapshot_ranges_parameters import TimeflowSnapshotRangesParameters
from delphix.api.gateway.model.timeflow_snapshot_ranges_response import TimeflowSnapshotRangesResponse
from delphix.api.gateway.model.timestamp_compatible_environments_response import TimestampCompatibleEnvironmentsResponse
from delphix.api.gateway.model.timestamp_compatible_repository_request import TimestampCompatibleRepositoryRequest
from delphix.api.gateway.model.token_info_request import TokenInfoRequest
from delphix.api.gateway.model.token_info_response import TokenInfoResponse
from delphix.api.gateway.model.toolkit import Toolkit
from delphix.api.gateway.model.toolkit_delete_job_response import ToolkitDeleteJobResponse
from delphix.api.gateway.model.toolkit_schema_definitions import ToolkitSchemaDefinitions
from delphix.api.gateway.model.toolkit_upload_job_response import ToolkitUploadJobResponse
from delphix.api.gateway.model.total_uses_response import TotalUsesResponse
from delphix.api.gateway.model.ui_profiles_request import UiProfilesRequest
from delphix.api.gateway.model.un_share_paa_s_snapshot_response import UnSharePaaSSnapshotResponse
from delphix.api.gateway.model.undo_refresh_vdb_response import UndoRefreshVDBResponse
from delphix.api.gateway.model.unregister_hyperscale_instance_response import UnregisterHyperscaleInstanceResponse
from delphix.api.gateway.model.unset_snapshot_retention_response import UnsetSnapshotRetentionResponse
from delphix.api.gateway.model.update_access_group_scope import UpdateAccessGroupScope
from delphix.api.gateway.model.update_app_data_d_source_parameters import UpdateAppDataDSourceParameters
from delphix.api.gateway.model.update_app_data_source_response import UpdateAppDataSourceResponse
from delphix.api.gateway.model.update_ase_d_source_parameters import UpdateAseDSourceParameters
from delphix.api.gateway.model.update_ase_source_response import UpdateAseSourceResponse
from delphix.api.gateway.model.update_bookmark_parameters import UpdateBookmarkParameters
from delphix.api.gateway.model.update_bookmark_response import UpdateBookmarkResponse
from delphix.api.gateway.model.update_cdb_parameters import UpdateCDBParameters
from delphix.api.gateway.model.update_cdb_response import UpdateCDBResponse
from delphix.api.gateway.model.update_cdb_d_source_parameters import UpdateCdbDSourceParameters
from delphix.api.gateway.model.update_cdb_d_source_response import UpdateCdbDSourceResponse
from delphix.api.gateway.model.update_cloud_account_parameters import UpdateCloudAccountParameters
from delphix.api.gateway.model.update_cloud_account_response import UpdateCloudAccountResponse
from delphix.api.gateway.model.update_compliance_application_setting_response import UpdateComplianceApplicationSettingResponse
from delphix.api.gateway.model.update_compliance_job_collection_request import UpdateComplianceJobCollectionRequest
from delphix.api.gateway.model.update_compliance_job_collection_response import UpdateComplianceJobCollectionResponse
from delphix.api.gateway.model.update_compliance_job_request import UpdateComplianceJobRequest
from delphix.api.gateway.model.update_compliance_job_response import UpdateComplianceJobResponse
from delphix.api.gateway.model.update_connector_response import UpdateConnectorResponse
from delphix.api.gateway.model.update_data_connection_response import UpdateDataConnectionResponse
from delphix.api.gateway.model.update_database_template_parameters import UpdateDatabaseTemplateParameters
from delphix.api.gateway.model.update_database_template_response import UpdateDatabaseTemplateResponse
from delphix.api.gateway.model.update_dsource_response import UpdateDsourceResponse
from delphix.api.gateway.model.update_engine_auto_tagging_config_response import UpdateEngineAutoTaggingConfigResponse
from delphix.api.gateway.model.update_environment_response import UpdateEnvironmentResponse
from delphix.api.gateway.model.update_environment_user_response import UpdateEnvironmentUserResponse
from delphix.api.gateway.model.update_hook_template_parameters import UpdateHookTemplateParameters
from delphix.api.gateway.model.update_host_response import UpdateHostResponse
from delphix.api.gateway.model.update_hyperscale_connector_response import UpdateHyperscaleConnectorResponse
from delphix.api.gateway.model.update_hyperscale_dataset_response import UpdateHyperscaleDatasetResponse
from delphix.api.gateway.model.update_hyperscale_dataset_table_or_file_response import UpdateHyperscaleDatasetTableOrFileResponse
from delphix.api.gateway.model.update_hyperscale_mount_point_response import UpdateHyperscaleMountPointResponse
from delphix.api.gateway.model.update_job_orchestrator_request import UpdateJobOrchestratorRequest
from delphix.api.gateway.model.update_job_orchestrator_response import UpdateJobOrchestratorResponse
from delphix.api.gateway.model.update_mssql_dsource_parameters import UpdateMSSQLDsourceParameters
from delphix.api.gateway.model.update_masking_job_parameters import UpdateMaskingJobParameters
from delphix.api.gateway.model.update_mssql_source_response import UpdateMssqlSourceResponse
from delphix.api.gateway.model.update_namespace_parameters import UpdateNamespaceParameters
from delphix.api.gateway.model.update_okv_client_parameters import UpdateOkvClientParameters
from delphix.api.gateway.model.update_okv_client_response import UpdateOkvClientResponse
from delphix.api.gateway.model.update_oracle_dsource_parameters import UpdateOracleDsourceParameters
from delphix.api.gateway.model.update_oracle_listener_params import UpdateOracleListenerParams
from delphix.api.gateway.model.update_oracle_listener_response import UpdateOracleListenerResponse
from delphix.api.gateway.model.update_oracle_source_response import UpdateOracleSourceResponse
from delphix.api.gateway.model.update_paa_s_instance_parameters import UpdatePaaSInstanceParameters
from delphix.api.gateway.model.update_paa_s_instance_response import UpdatePaaSInstanceResponse
from delphix.api.gateway.model.update_postgres_source_response import UpdatePostgresSourceResponse
from delphix.api.gateway.model.update_replication_profile_parameters import UpdateReplicationProfileParameters
from delphix.api.gateway.model.update_repository_parameters import UpdateRepositoryParameters
from delphix.api.gateway.model.update_repository_response import UpdateRepositoryResponse
from delphix.api.gateway.model.update_snapshot_parameters import UpdateSnapshotParameters
from delphix.api.gateway.model.update_snapshot_response import UpdateSnapshotResponse
from delphix.api.gateway.model.update_source_parameters import UpdateSourceParameters
from delphix.api.gateway.model.update_source_response import UpdateSourceResponse
from delphix.api.gateway.model.update_staging_cdb_parameters import UpdateStagingCdbParameters
from delphix.api.gateway.model.update_staging_cdb_response import UpdateStagingCdbResponse
from delphix.api.gateway.model.update_staging_source_parameters import UpdateStagingSourceParameters
from delphix.api.gateway.model.update_staging_source_response import UpdateStagingSourceResponse
from delphix.api.gateway.model.update_timeflow_parameters import UpdateTimeflowParameters
from delphix.api.gateway.model.update_timeflow_response import UpdateTimeflowResponse
from delphix.api.gateway.model.update_vcdb_parameters import UpdateVCDBParameters
from delphix.api.gateway.model.update_vcdb_response import UpdateVCDBResponse
from delphix.api.gateway.model.update_vdb_group_parameters import UpdateVDBGroupParameters
from delphix.api.gateway.model.update_vdb_parameters import UpdateVDBParameters
from delphix.api.gateway.model.update_vdb_response import UpdateVDBResponse
from delphix.api.gateway.model.update_virtualization_policy_parameters import UpdateVirtualizationPolicyParameters
from delphix.api.gateway.model.upgrade_cdbd_source_response import UpgradeCDBDSourceResponse
from delphix.api.gateway.model.upgrade_cdb_response import UpgradeCDBResponse
from delphix.api.gateway.model.upgrade_compatible_environments_response import UpgradeCompatibleEnvironmentsResponse
from delphix.api.gateway.model.upgrade_database_parameters import UpgradeDatabaseParameters
from delphix.api.gateway.model.upgrade_dsource_response import UpgradeDsourceResponse
from delphix.api.gateway.model.upgrade_oracle_container_database_parameters import UpgradeOracleContainerDatabaseParameters
from delphix.api.gateway.model.upgrade_oracle_database_parameters import UpgradeOracleDatabaseParameters
from delphix.api.gateway.model.upgrade_staging_cdb_response import UpgradeStagingCDBResponse
from delphix.api.gateway.model.upgrade_vcdb_response import UpgradeVCDBResponse
from delphix.api.gateway.model.upgrade_vdb_response import UpgradeVDBResponse
from delphix.api.gateway.model.vcdb import VCDB
from delphix.api.gateway.model.vdb import VDB
from delphix.api.gateway.model.vdb_disable_parameters_mapping import VDBDisableParametersMapping
from delphix.api.gateway.model.vdb_disable_parameters_mapping_all_of import VDBDisableParametersMappingAllOf
from delphix.api.gateway.model.vdb_enable_parameters_mapping import VDBEnableParametersMapping
from delphix.api.gateway.model.vdb_enable_parameters_mapping_all_of import VDBEnableParametersMappingAllOf
from delphix.api.gateway.model.vdb_group import VDBGroup
from delphix.api.gateway.model.vdb_group_refresh_by_snapshot import VDBGroupRefreshBySnapshot
from delphix.api.gateway.model.vdb_group_refresh_by_timestamp import VDBGroupRefreshByTimestamp
from delphix.api.gateway.model.vdb_group_timestamp_summary_request import VDBGroupTimestampSummaryRequest
from delphix.api.gateway.model.vdb_inventory_data import VDBInventoryData
from delphix.api.gateway.model.vdb_inventory_report_response import VDBInventoryReportResponse
from delphix.api.gateway.model.vdb_order import VDBOrder
from delphix.api.gateway.model.vdb_order_all_of import VDBOrderAllOf
from delphix.api.gateway.model.vdb_start_parameters_mapping import VDBStartParametersMapping
from delphix.api.gateway.model.vdb_start_parameters_mapping_all_of import VDBStartParametersMappingAllOf
from delphix.api.gateway.model.vdb_stop_parameters_mapping import VDBStopParametersMapping
from delphix.api.gateway.model.vdb_stop_parameters_mapping_all_of import VDBStopParametersMappingAllOf
from delphix.api.gateway.model.validate_java_parameters import ValidateJavaParameters
from delphix.api.gateway.model.vdb_group_timestamp_summary import VdbGroupTimestampSummary
from delphix.api.gateway.model.vdb_group_timestamp_summary_item import VdbGroupTimestampSummaryItem
from delphix.api.gateway.model.vdb_group_timestamp_summary_response import VdbGroupTimestampSummaryResponse
from delphix.api.gateway.model.virtual_dataset_hooks import VirtualDatasetHooks
from delphix.api.gateway.model.virtualization_action import VirtualizationAction
from delphix.api.gateway.model.virtualization_alert import VirtualizationAlert
from delphix.api.gateway.model.virtualization_fault import VirtualizationFault
from delphix.api.gateway.model.virtualization_fault_resolve_all_job_response import VirtualizationFaultResolveAllJobResponse
from delphix.api.gateway.model.virtualization_fault_resolve_job_response import VirtualizationFaultResolveJobResponse
from delphix.api.gateway.model.virtualization_fault_resolve_or_ignore_job_response import VirtualizationFaultResolveOrIgnoreJobResponse
from delphix.api.gateway.model.virtualization_fault_resolve_or_ignore_parameters import VirtualizationFaultResolveOrIgnoreParameters
from delphix.api.gateway.model.virtualization_fault_resolve_parameters import VirtualizationFaultResolveParameters
from delphix.api.gateway.model.virtualization_job import VirtualizationJob
from delphix.api.gateway.model.virtualization_job_event import VirtualizationJobEvent
from delphix.api.gateway.model.virtualization_policy import VirtualizationPolicy
from delphix.api.gateway.model.virtualization_policy_apply_params import VirtualizationPolicyApplyParams
from delphix.api.gateway.model.virtualization_policy_apply_response import VirtualizationPolicyApplyResponse
from delphix.api.gateway.model.virtualization_policy_convert_job_response import VirtualizationPolicyConvertJobResponse
from delphix.api.gateway.model.virtualization_policy_delete_job_response import VirtualizationPolicyDeleteJobResponse
from delphix.api.gateway.model.virtualization_policy_target import VirtualizationPolicyTarget
from delphix.api.gateway.model.virtualization_policy_unapply_response import VirtualizationPolicyUnapplyResponse
from delphix.api.gateway.model.virtualization_policy_update_job_response import VirtualizationPolicyUpdateJobResponse
from delphix.api.gateway.model.virtualization_schedule import VirtualizationSchedule
from delphix.api.gateway.model.virtualization_storage_summary_data import VirtualizationStorageSummaryData
from delphix.api.gateway.model.virtualization_storage_summary_report_response import VirtualizationStorageSummaryReportResponse
from delphix.api.gateway.model.virtualization_task import VirtualizationTask
from delphix.api.gateway.model.virtualization_task_event import VirtualizationTaskEvent



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from delphix.api.gateway.api_client import ApiClient, Endpoint as _Endpoint
from delphix.api.gateway.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from delphix.api.gateway.model.list_virtualization_faults_response import ListVirtualizationFaultsResponse
from delphix.api.gateway.model.search_body import SearchBody
from delphix.api.gateway.model.search_virtualization_faults_response import SearchVirtualizationFaultsResponse
from delphix.api.gateway.model.virtualization_fault_resolve_all_job_response import VirtualizationFaultResolveAllJobResponse
from delphix.api.gateway.model.virtualization_fault_resolve_job_response import VirtualizationFaultResolveJobResponse
from delphix.api.gateway.model.virtualization_fault_resolve_or_ignore_job_response import VirtualizationFaultResolveOrIgnoreJobResponse
from delphix.api.gateway.model.virtualization_fault_resolve_or_ignore_parameters import VirtualizationFaultResolveOrIgnoreParameters
from delphix.api.gateway.model.virtualization_fault_resolve_parameters import VirtualizationFaultResolveParameters


class VirtualizationFaultsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        def __get_virtualization_faults_history(
            self,
            **kwargs
        ):
            """Fetch a list of all virtualization faults  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_virtualization_faults_history(async_req=True)
            >>> result = thread.get()


            Keyword Args:
                limit (int): Maximum number of objects to return per query. The value must be between 1 and 1000. Default is 100.. [optional] if omitted the server will use the default value of 100
                cursor (str): Cursor to fetch the next or previous page of results. The value of this property must be extracted from the 'prev_cursor' or 'next_cursor' property of a PaginatedResponseMetadata which is contained in the response of list and search API endpoints.. [optional]
                sort (str, none_type): The field to sort results by. A property name with a prepended '-' signifies descending order.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ListVirtualizationFaultsResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            return self.call_with_http_info(**kwargs)

        self.get_virtualization_faults_history = _Endpoint(
            settings={
                'response_type': (ListVirtualizationFaultsResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/virtualization-faults/history',
                'operation_id': 'get_virtualization_faults_history',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'limit',
                    'cursor',
                    'sort',
                ],
                'required': [],
                'nullable': [
                    'sort',
                ],
                'enum': [
                    'sort',
                ],
                'validation': [
                    'limit',
                    'cursor',
                ]
            },
            root_map={
                'validations': {
                    ('limit',): {

                        'inclusive_maximum': 1000,
                        'inclusive_minimum': 1,
                    },
                    ('cursor',): {
                        'max_length': 4096,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                    ('sort',): {
                        'None': None,
                        "ID": "id",
                        "-ID": "-id",
                        "ENGINE_ID": "engine_id",
                        "-ENGINE_ID": "-engine_id",
                        "BUNDLE_ID": "bundle_id",
                        "-BUNDLE_ID": "-bundle_id",
                        "TARGET_NAME": "target_name",
                        "-TARGET_NAME": "-target_name",
                        "TARGET_OBJECT_TYPE": "target_object_type",
                        "-TARGET_OBJECT_TYPE": "-target_object_type",
                        "TARGET_OBJECT_ID": "target_object_id",
                        "-TARGET_OBJECT_ID": "-target_object_id",
                        "TITLE": "title",
                        "-TITLE": "-title",
                        "DESCRIPTION": "description",
                        "-DESCRIPTION": "-description",
                        "FAULT_ACTION": "fault_action",
                        "-FAULT_ACTION": "-fault_action",
                        "RESPONSE": "response",
                        "-RESPONSE": "-response",
                        "SEVERITY": "severity",
                        "-SEVERITY": "-severity",
                        "STATUS": "status",
                        "-STATUS": "-status",
                        "DATE_DIAGNOSED": "date_diagnosed",
                        "-DATE_DIAGNOSED": "-date_diagnosed",
                        "DATE_RESOLVED": "date_resolved",
                        "-DATE_RESOLVED": "-date_resolved",
                        "RESOLUTION_COMMENTS": "resolution_comments",
                        "-RESOLUTION_COMMENTS": "-resolution_comments"
                    },
                },
                'openapi_types': {
                    'limit':
                        (int,),
                    'cursor':
                        (str,),
                    'sort':
                        (str, none_type,),
                },
                'attribute_map': {
                    'limit': 'limit',
                    'cursor': 'cursor',
                    'sort': 'sort',
                },
                'location_map': {
                    'limit': 'query',
                    'cursor': 'query',
                    'sort': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json',
                    'text/csv'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_virtualization_faults_history
        )

        def __resolve_all_virtualization_faults(
            self,
            engine_id,
            **kwargs
        ):
            """Marks all active faults of an engine that the user has permissions over as resolved.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.resolve_all_virtualization_faults(engine_id, async_req=True)
            >>> result = thread.get()

            Args:
                engine_id (str): The ID of the registered engine.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                VirtualizationFaultResolveAllJobResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['engine_id'] = \
                engine_id
            return self.call_with_http_info(**kwargs)

        self.resolve_all_virtualization_faults = _Endpoint(
            settings={
                'response_type': (VirtualizationFaultResolveAllJobResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/virtualization-faults/{engineId}/resolveAll',
                'operation_id': 'resolve_all_virtualization_faults',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'engine_id',
                ],
                'required': [
                    'engine_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'engine_id':
                        (str,),
                },
                'attribute_map': {
                    'engine_id': 'engineId',
                },
                'location_map': {
                    'engine_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__resolve_all_virtualization_faults
        )

        def __resolve_or_ignore_virtualization_faults(
            self,
            **kwargs
        ):
            """Marks selected faults as resolved or ignored.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.resolve_or_ignore_virtualization_faults(async_req=True)
            >>> result = thread.get()


            Keyword Args:
                virtualization_fault_resolve_or_ignore_parameters (VirtualizationFaultResolveOrIgnoreParameters): [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                VirtualizationFaultResolveOrIgnoreJobResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            return self.call_with_http_info(**kwargs)

        self.resolve_or_ignore_virtualization_faults = _Endpoint(
            settings={
                'response_type': (VirtualizationFaultResolveOrIgnoreJobResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/virtualization-faults/resolveOrIgnore',
                'operation_id': 'resolve_or_ignore_virtualization_faults',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'virtualization_fault_resolve_or_ignore_parameters',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'virtualization_fault_resolve_or_ignore_parameters':
                        (VirtualizationFaultResolveOrIgnoreParameters,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'virtualization_fault_resolve_or_ignore_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__resolve_or_ignore_virtualization_faults
        )

        def __resolve_virtualization_fault(
            self,
            fault_id,
            **kwargs
        ):
            """Marks the fault as resolved. The Delphix engine will attempt to automatically detect cases where the fault has been resolved; but this is not always possible and may only occur on periodic intervals. In these cases, the user can proactively mark the fault resolved. This does not change the underlying disposition of the fault - if the problem is still present the system may immediately diagnose the same problem again. This should only be used to notify the system of resolution after the underlying problem has been resolved.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.resolve_virtualization_fault(fault_id, async_req=True)
            >>> result = thread.get()

            Args:
                fault_id (str): The ID of the Virtualization Fault.

            Keyword Args:
                virtualization_fault_resolve_parameters (VirtualizationFaultResolveParameters): [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                VirtualizationFaultResolveJobResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['fault_id'] = \
                fault_id
            return self.call_with_http_info(**kwargs)

        self.resolve_virtualization_fault = _Endpoint(
            settings={
                'response_type': (VirtualizationFaultResolveJobResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/virtualization-fault/{faultId}/resolve',
                'operation_id': 'resolve_virtualization_fault',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'fault_id',
                    'virtualization_fault_resolve_parameters',
                ],
                'required': [
                    'fault_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'fault_id',
                ]
            },
            root_map={
                'validations': {
                    ('fault_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'fault_id':
                        (str,),
                    'virtualization_fault_resolve_parameters':
                        (VirtualizationFaultResolveParameters,),
                },
                'attribute_map': {
                    'fault_id': 'faultId',
                },
                'location_map': {
                    'fault_id': 'path',
                    'virtualization_fault_resolve_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__resolve_virtualization_fault
        )

        def __search_virtualization_faults_history(
            self,
            **kwargs
        ):
            """Search virtualization faults  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.search_virtualization_faults_history(async_req=True)
            >>> result = thread.get()


            Keyword Args:
                limit (int): Maximum number of objects to return per query. The value must be between 1 and 1000. Default is 100.. [optional] if omitted the server will use the default value of 100
                cursor (str): Cursor to fetch the next or previous page of results. The value of this property must be extracted from the 'prev_cursor' or 'next_cursor' property of a PaginatedResponseMetadata which is contained in the response of list and search API endpoints.. [optional]
                sort (str, none_type): The field to sort results by. A property name with a prepended '-' signifies descending order.. [optional]
                search_body (SearchBody): A request body containing a filter expression. This enables searching for items matching arbitrarily complex conditions. The list of attributes which can be used in filter expressions is available in the x-filterable vendor extension.  # Filter Expression Overview **Note: All keywords are case-insensitive**  ## Comparison Operators | Operator | Description | Example | | --- | --- | --- | | CONTAINS | Substring or membership testing for string and list attributes respectively. | field3 CONTAINS 'foobar', field4 CONTAINS TRUE  | | IN | Tests if field is a member of a list literal. List can contain a maximum of 100 values | field2 IN ['Goku', 'Vegeta'] | | GE | Tests if a field is greater than or equal to a literal value | field1 GE 1.2e-2 | | GT | Tests if a field is greater than a literal value | field1 GT 1.2e-2 | | LE | Tests if a field is less than or equal to a literal value | field1 LE 9000 | | LT | Tests if a field is less than a literal value | field1 LT 9.02 | | NE | Tests if a field is not equal to a literal value | field1 NE 42 | | EQ | Tests if a field is equal to a literal value | field1 EQ 42 |  ## Search Operator The SEARCH operator filters for items which have any filterable attribute that contains the input string as a substring, comparison is done case-insensitively. This is not restricted to attributes with string values. Specifically `SEARCH '12'` would match an item with an attribute with an integer value of `123`.  ## Logical Operators Ordered by precedence. | Operator | Description | Example | | --- | --- | --- | | NOT | Logical NOT (Right associative) | NOT field1 LE 9000 | | AND | Logical AND (Left Associative) | field1 GT 9000 AND field2 EQ 'Goku' | | OR | Logical OR (Left Associative) | field1 GT 9000 OR field2 EQ 'Goku' |  ## Grouping Parenthesis `()` can be used to override operator precedence.  For example: NOT (field1 LT 1234 AND field2 CONTAINS 'foo')  ## Literal Values | Literal      | Description | Examples | | --- | --- | --- | | Nil | Represents the absence of a value | nil, Nil, nIl, NIL | | Boolean | true/false boolean | true, false, True, False, TRUE, FALSE | | Number | Signed integer and floating point numbers. Also supports scientific notation. | 0, 1, -1, 1.2, 0.35, 1.2e-2, -1.2e+2 | | String | Single or double quoted | \"foo\", \"bar\", \"foo bar\", 'foo', 'bar', 'foo bar' | | Datetime | Formatted according to [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339) | 2018-04-27T18:39:26.397237+00:00 | | List | Comma-separated literals wrapped in square brackets | [0], [0, 1], ['foo', \"bar\"] |  ## Limitations - A maximum of 8 unique identifiers may be used inside a filter expression. . [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                SearchVirtualizationFaultsResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            return self.call_with_http_info(**kwargs)

        self.search_virtualization_faults_history = _Endpoint(
            settings={
                'response_type': (SearchVirtualizationFaultsResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/virtualization-faults/history/search',
                'operation_id': 'search_virtualization_faults_history',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'limit',
                    'cursor',
                    'sort',
                    'search_body',
                ],
                'required': [],
                'nullable': [
                    'sort',
                ],
                'enum': [
                    'sort',
                ],
                'validation': [
                    'limit',
                    'cursor',
                ]
            },
            root_map={
                'validations': {
                    ('limit',): {

                        'inclusive_maximum': 1000,
                        'inclusive_minimum': 1,
                    },
                    ('cursor',): {
                        'max_length': 4096,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                    ('sort',): {
                        'None': None,
                        "ID": "id",
                        "-ID": "-id",
                        "ENGINE_ID": "engine_id",
                        "-ENGINE_ID": "-engine_id",
                        "BUNDLE_ID": "bundle_id",
                        "-BUNDLE_ID": "-bundle_id",
                        "TARGET_NAME": "target_name",
                        "-TARGET_NAME": "-target_name",
                        "TARGET_OBJECT_TYPE": "target_object_type",
                        "-TARGET_OBJECT_TYPE": "-target_object_type",
                        "TARGET_OBJECT_ID": "target_object_id",
                        "-TARGET_OBJECT_ID": "-target_object_id",
                        "TITLE": "title",
                        "-TITLE": "-title",
                        "DESCRIPTION": "description",
                        "-DESCRIPTION": "-description",
                        "FAULT_ACTION": "fault_action",
                        "-FAULT_ACTION": "-fault_action",
                        "RESPONSE": "response",
                        "-RESPONSE": "-response",
                        "SEVERITY": "severity",
                        "-SEVERITY": "-severity",
                        "STATUS": "status",
                        "-STATUS": "-status",
                        "DATE_DIAGNOSED": "date_diagnosed",
                        "-DATE_DIAGNOSED": "-date_diagnosed",
                        "DATE_RESOLVED": "date_resolved",
                        "-DATE_RESOLVED": "-date_resolved",
                        "RESOLUTION_COMMENTS": "resolution_comments",
                        "-RESOLUTION_COMMENTS": "-resolution_comments"
                    },
                },
                'openapi_types': {
                    'limit':
                        (int,),
                    'cursor':
                        (str,),
                    'sort':
                        (str, none_type,),
                    'search_body':
                        (SearchBody,),
                },
                'attribute_map': {
                    'limit': 'limit',
                    'cursor': 'cursor',
                    'sort': 'sort',
                },
                'location_map': {
                    'limit': 'query',
                    'cursor': 'query',
                    'sort': 'query',
                    'search_body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json',
                    'text/csv'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__search_virtualization_faults_history
        )



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.staging_sources_api import StagingSourcesApi  # noqa: E501


class TestStagingSourcesApi(unittest.TestCase):
    """StagingSourcesApi unit test stubs"""

    def setUp(self):
        self.api = StagingSourcesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_staging_source_tags(self):
        """Test case for create_staging_source_tags

        Create tags for a Staging Source.  # noqa: E501
        """
        pass

    def test_delete_staging_source_tags(self):
        """Test case for delete_staging_source_tags

        Delete tags for a Staging Source.  # noqa: E501
        """
        pass

    def test_get_staging_source_by_id(self):
        """Test case for get_staging_source_by_id

        Get a staging source by ID.  # noqa: E501
        """
        pass

    def test_get_staging_source_tags(self):
        """Test case for get_staging_source_tags

        Get tags for a Staging Source.  # noqa: E501
        """
        pass

    def test_get_staging_sources(self):
        """Test case for get_staging_sources

        List all staging sources.  # noqa: E501
        """
        pass

    def test_search_staging_sources(self):
        """Test case for search_staging_sources

        Search for Staging Sources.  # noqa: E501
        """
        pass

    def test_update_staging_source_by_id(self):
        """Test case for update_staging_source_by_id

        Update a Staging Source.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.compliance_jobs_api import ComplianceJobsApi  # noqa: E501


class TestComplianceJobsApi(unittest.TestCase):
    """ComplianceJobsApi unit test stubs"""

    def setUp(self):
        self.api = ComplianceJobsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_compliance_job(self):
        """Test case for create_compliance_job

        Create a Compliance Job.  # noqa: E501
        """
        pass

    def test_create_compliance_job_tag(self):
        """Test case for create_compliance_job_tag

        Create tags for a compliance job.  # noqa: E501
        """
        pass

    def test_delete_compliance_job(self):
        """Test case for delete_compliance_job

        Delete a compliance job.  # noqa: E501
        """
        pass

    def test_delete_compliance_job_tag(self):
        """Test case for delete_compliance_job_tag

        Delete tags for a compliance job.  # noqa: E501
        """
        pass

    def test_execute_compliance_job(self):
        """Test case for execute_compliance_job

        Execute a compliance job.  # noqa: E501
        """
        pass

    def test_get_compliance_job_by_id(self):
        """Test case for get_compliance_job_by_id

        Retrieve a compliance job by ID.  # noqa: E501
        """
        pass

    def test_get_compliance_job_connectors(self):
        """Test case for get_compliance_job_connectors

        Get connectors for a Masking Job by ID.  # noqa: E501
        """
        pass

    def test_get_compliance_job_tag(self):
        """Test case for get_compliance_job_tag

        Get tags for a compliance job.  # noqa: E501
        """
        pass

    def test_get_compliance_jobs(self):
        """Test case for get_compliance_jobs

        Retrieve the list of compliance jobs.  # noqa: E501
        """
        pass

    def test_search_compliance_jobs(self):
        """Test case for search_compliance_jobs

        Search compliance jobs.  # noqa: E501
        """
        pass

    def test_update_compliance_job(self):
        """Test case for update_compliance_job

        Update values of a compliance job.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import delphix.api.gateway
from delphix.api.gateway.model.paginated_response_metadata import PaginatedResponseMetadata
from delphix.api.gateway.model.queued_operation import QueuedOperation
globals()['PaginatedResponseMetadata'] = PaginatedResponseMetadata
globals()['QueuedOperation'] = QueuedOperation
from delphix.api.gateway.model.list_job_orchestrator_queued_operations_response import ListJobOrchestratorQueuedOperationsResponse


class TestListJobOrchestratorQueuedOperationsResponse(unittest.TestCase):
    """ListJobOrchestratorQueuedOperationsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListJobOrchestratorQueuedOperationsResponse(self):
        """Test ListJobOrchestratorQueuedOperationsResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListJobOrchestratorQueuedOperationsResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
